/**
 * 根据状态条件获取帮助人列表
 * @param orderID  求助订单
 * @param state   帮助人的状态
 * @param type   确定是在哪个页面
 * @param successCallback
 * @param errorCallback
 */
function getHelperLists(type,orderID,state,successCallback,errorCallback){
	var HelperList = Bmob.Object.extend("HelperList");
    var query = new Bmob.Query(HelperList);
    orderID = Number(orderID);
    query.equalTo("orderID",orderID);
    query.ascending("createdAt");
    if(type == "helpSelect"){
    	query.equalTo("state",state);
    }else if(type == "helpWait"){
    	query.equalTo("state",state);
    }else if(type == "helpCheck"){
    	query.greaterThanOrEqualTo("state",state);
    }else if(type == "helpWaitEvaluation"){
    	query.equalTo("state",state);
    }else if(type == "success"){
    	query.equalTo("state",state);
    }
    query.find({
        success: function (results) {
            successCallback(results);
        },
        error: function (error) {
            errorCallback(error);
        }
    });
}

function getHelperListsV2(type,orderRecord,successCallback,errorCallback){
	var HelperList = Bmob.Object.extend("HelperList");
    var query = new Bmob.Query(HelperList);
    orderID = orderRecord.get("orderID");
    query.equalTo("orderID",orderID);
    query.containedIn("ownerID",orderRecord.get("selectList"))
    query.ascending("createdAt");
    query.find({
        success: function (results) {
            successCallback(results);
        },
        error: function (error) {
            errorCallback(error);
        }
    });
}

function bmobChangeObj(results){
	var objEnrollList = {} 
	var keys = ["orderID","classID","ownerID","orderName","payment","helperNum","helperSex","beginTime","applyDeadlineTime","place","description","photo","ID","orderGeo","repeatTimes","TaskEvaluation","askerAppraisement","helperAppraisement","repeatTimes","skillID"];
	bmob2Obj(keys, results, objEnrollList);
	objEnrollList.updatedAt = results.updatedAt;
    transBeginTime(objEnrollList);
	var group = results.get('group');
	objEnrollList.avatar = '../../../image/helpGroup.png';
	var keys2 = ["groupName","rongyunID","avatar","groupID"];
	bmob2Obj(keys2, group, objEnrollList);
	gGroupName = objEnrollList.groupName;
	gGroupID = objEnrollList.rongyunID;
	return objEnrollList;
}


/**
 * 根据页面不同获取求助信息以及显示页面
 * @param type   确定是在哪个页面
 * @param successCallback
 * @param errorCallback
 */
function getCommonHelpOrder(type,successCallback,errCallback){
	if(!successCallback)successCallback = function(){};
	if(!errCallback)errCallback = function(){};
	GetHelpOrder(orderID,function(results){
		consoledebug.log('initData GetHelpOrderInfo results is '+ JSON.stringify(results));
		gOrderRecord = results;
		var objEnrollList = bmobChangeObj(results);
		switch(type){
			case "helpSelect":
			 	gGroupNumberID = objEnrollList.groupID;
				uiSelectCandidateHelp(objEnrollList);
				//uiSelectCandidateHelpInfo(objEnrollList);
				issureFooter();
	        break;
	        case "helpWait":
				uiSelectCandidateHelp(objEnrollList);
				uiSelectCandidateHelpInfo(objEnrollList);
	        break;
	        case "helpCheck":
				uiAcceptanceHelp(objEnrollList);
				uiAcceptanceHelpInfo(objEnrollList);
				if(objEnrollList.skillID){
					$api.css($api.byId("comment_con"),"display:block");
				}
	        break;
	        case "helpWaitEvaluation":
				uiWaitEvaluateHelp(objEnrollList);
				uiWaitEvaluateHelpInfo(objEnrollList)
	        break;
	        case "success":
				uiHelpCompletedHelp(objEnrollList);
				uiHelpCompletedHelpInfo(objEnrollList)
	        break;
	        case "helpQuit":
				uiSelectCandidateHelp(objEnrollList);
				uiSelectCandidateHelpInfo(objEnrollList);
	        break;
		}
		successCallback(gOrderRecord);
	},function(error){
       	consoledebug.log("GetHelpOrder fail "+JSON.stringify(error));
       	errCallback(error);
	});
}

/**
 * 根据页面不同获取求助人列表
 * @param type   确定是在哪个页面
 * @param successCallback
 * @param errorCallback
 */
function getCommonHelpList(type,orderID,state){
	getHelperLists(type,orderID,state,function(enrollList){
		consoledebug.log("getCommonHelpList enrollList is  "+JSON.stringify(enrollList));
		gMyhelperOrder = enrollList;
		helperListRecord = enrollList;
		hhIDs = [];
		for(var i=0;i<enrollList.length;i++){
			hhIDs.push(enrollList[i].get('ownerID'));
		}
		consoledebug.log("hhIDs is " + JSON.stringify(hhIDs));
		getComAllUserInfo(hhIDs, function(userInfos){
			consoledebug.log("getComAllUserInfo userInfos is  "+JSON.stringify(userInfos));
			switch(type){
				case "helpSelect":
				 	uiSelectCandidate(userInfos);
		        break;
		        case "helpWait":
					for(var i=0;i<gMyhelperOrder.length;i++){
						for(var j=0;j<userInfos.length;j++){
							if(userInfos[j].hhID == gMyhelperOrder[i].get("ownerID")){
								if( gMyhelperOrder[i].get("state")==HELPER_ORDER_RUNNING){
									userInfos[j].state = "帮助中";
								}else{
									userInfos[j].state = "已完成";
								}
							}
						}
					}
					uiGetSelectedCandidate(userInfos);
					uiGetCancelTheHelpCandidate(gMyhelperOrder);
		        break;
		        case "helpCheck":
					uiAcceptanceHelper(userInfos);
		        break;
		        case "helpWaitEvaluation":
					uiWaitEvaluateHelper(userInfos);
					uiWaitEvaluateAppraisement(gMyhelperOrder);
		        break;
		        case "success":
					uiHelpCompletedHelper(userInfos)
					uiHelpCompletedAppraisement(gMyhelperOrder);
		        break;
		        case "helpQuit":
					uiQuitExamineHelper(userInfos);
		        break;
			}
		},function(error){
	        consoledebug.log("getCommonHelpList getComAllUserInfo is error "+JSON.stringify(error));
		});
	},function(error){
       	consoledebug.log("getHelperLists fail "+JSON.stringify(error));
	});
}

function getCommonHelpListV2(type,orderRecord,state){
	if(orderRecord.get("selectList")){
		getHelperListsV2(type,orderRecord,successCallback,errorCallback)
	}else{
		getHelperLists(type,orderID,state,successCallback,errorCallback)
	}
	function successCallback(enrollList){
		consoledebug.log("getCommonHelpList enrollList is  "+JSON.stringify(enrollList));
		gMyhelperOrder = enrollList;
		helperListRecord = enrollList;
		hhIDs = [];
		for(var i=0;i<enrollList.length;i++){
			hhIDs.push(enrollList[i].get('ownerID'));
		}
		consoledebug.log("hhIDs is " + JSON.stringify(hhIDs));
		getComAllUserInfo(hhIDs, function(userInfos){
			consoledebug.log("getComAllUserInfo userInfos is  "+JSON.stringify(userInfos));
			switch(type){
				case "helpSelect":
				 	uiSelectCandidate(userInfos);
		        break;
		        case "helpWait":
		        	var helperInfos = [];
		        	var quiterInfos = []
					for(var i=0;i<gMyhelperOrder.length;i++){
						for(var j=0;j<userInfos.length;j++){
							if(userInfos[j].hhID == gMyhelperOrder[i].get("ownerID")){
								if( gMyhelperOrder[i].get("state")==HELPER_ORDER_RUNNING){
									userInfos[j].state = "帮助中";
									helperInfos.push(userInfos[j]);
								}else if(gMyhelperOrder[i].get("state")==HELPER_ORDER_CHECKING){
									userInfos[j].state = "已完成";
									helperInfos.push(userInfos[j]);
								}else{
									userInfos[j].state = "已退出";
									quiterInfos.push(userInfos[j]);
								}
							}
						}
					}
					uiGetSelectedCandidate(helperInfos);
					uiGetCancelTheHelpCandidate(quiterInfos);
		        break;
		        case "helpCheck":
					uiAcceptanceHelper(userInfos);
		        break;
		        case "helpWaitEvaluation":
					uiWaitEvaluateHelper(userInfos);
					uiWaitEvaluateAppraisement(gMyhelperOrder);
		        break;
		        case "success":
					uiHelpCompletedHelper(userInfos)
					uiHelpCompletedAppraisement(gMyhelperOrder);
		        break;
		        case "helpQuit":
					uiQuitExamineHelper(userInfos);
		        break;
			}
		},function(error){
	        consoledebug.log("getCommonHelpList getComAllUserInfo is error "+JSON.stringify(error));
		});
	}
	function errorCallback(error){
       	consoledebug.log("getHelperLists fail "+JSON.stringify(error));
	}
}

//点击头像跳转到详情页
function openUserInfo(el){
    var hhID = $api.attr(el, 'id');
    hhID=Number(hhID);
    consoledebug.log('openUserInfo id is '+ hhID +typeof(hhID));
    comOpenWin('otherUserInfo','../../user/',hhID,0);
}




