var MESSAGES_TABLE_NAME = "HistoryMessages";
//var RONGYUN_SDK = "rongCloud";

  /**
   * 从网上更新与某个会话的聊天记录
   *
   * @param {Number} targetId, 交谈对象的用户ID，如果是用户，则为 hhID，如果是组，则为 rongyunID
   * @param {String} conversationType, 会话类型
   * @param {function} initCallback 本地获取的数据，用于初始化列表，定义为 .
   * 		initCallback(messages); messages 是 {Object[]} 对象数组，数组按 messageID 降序排列，因此在页面中数组应往上逐条添加
   * 		包含的 属性举例如下：
		    [
		        {
		            content: {
		                text: 'Hello world!',
		                extra: ''
		            }, // 消息内容
		            conversationType: 'PRIVATE', // 参见 会话类型 枚举
		            messageDirection: 'SEND', // 消息方向：SEND 或者 RECEIVE
		            targetId: '55', // 这里对应消息发送者的 userId
		            objectName: 'RC:TxtMsg', // 消息类型，参见 http://docs.rongcloud.cn/android_message.html#_内置内容类消息
		            sentStatus: 'SENDING', // 发送状态：SENDING, SENT 或 FAILED
		            senderUserId: '55', // 发送者 userId
		            messageId: 608, // 本地消息 Id
		            sentTime: 1418971531533, // 发送消息的时间戳，从 1970 年 1 月 1 日 0 点 0 分 0 秒开始到现在的毫秒数
		            receivedTime: 0 // 收到消息的时间戳，从 1970 年 1 月 1 日 0 点 0 分 0 秒开始到现在的毫秒数
		        }
		    ]
   * @param {function} updateCallback 从网络获取的更新数据，数据定义与 initCallback 一样.
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(); }
   */
function updateHistoryMessages(targetId, conversationType, lastMessageId, updateCallback, errorCallback) {
    consoledebug.log('updateHistoryMessages lastMessageId is ' + typeof lastMessageId + lastMessageId);
    //从朋友列表或组列表点击进入对话页面时，lastMessageId 传递的为 -1，不需网络更新
    if(lastMessageId == -1){
        return;
    }
    var rong = api.require(RONGYUN_SDK);
	rong.getLatestMessages({
		conversationType : conversationType,
		targetId : targetId+"",
        count: lastMessageId - gNewestMessage.messageId
	}, function(ret, err) {
		if (ret.status == 'success') {
			if (ret.result && ret.result.length > 0) {
				updateCallback(ret.result);
				insertCacheHistoryMessages(ret.result, function() {
//					rong.deleteMessages({
//						messageIds : [ret.result[0].messageId]
//					}, function(ret, err) {
//			        	consoledebug.log('rong deleteMessages is ' + ret.status);
//					});
				}, function(err) {
					consoledebug.log('insertCacheHistoryMessages error is ' + err.msg);
				});
			}
		} else {
			consoledebug.log('rong getHistoryMessages error is ' + err.msg);
			errorCallback(err);
		}
	})
}

  /**
   * 获取对话列表
   * @param {function} successCallback 成功获取后回调函数，定义为 .
   *        successCallback(HistoryMessages); HistoryMessages 是 {Object[]} json 对象数组
   * 包含的key 为：见头部消息定义
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function getInitCacheHistoryMessages(targetId, successCallback, errorCallback){
    var	sql = 'SELECT * FROM ' + MESSAGES_TABLE_NAME + " where targetId = '"+ targetId + "' ORDER BY messageId DESC LIMIT " + 50 + ';';
    selectSql(sql, function(HistoryMessages){
        for(var i = 0; i < HistoryMessages.length; i++) {
            var content = JSON.parse(HistoryMessages[i].content);
            HistoryMessages[i].content = content;
            HistoryMessages[i].sentTime = Number(HistoryMessages[i].sentTime);
            HistoryMessages[i].receivedTime = Number(HistoryMessages[i].receivedTime);
            //consoledebug.log('getCacheHistoryMessages i latestMessage.text is ' + HistoryMessages[i].latestMessage.text);
        }
        if(i > 0){
        	gOldestMessage = HistoryMessages[i-1];
        	gNewestMessage = HistoryMessages[0];
        }
		consoledebug.log('getCacheHistoryMessages gOldestMessage is ' + gOldestMessage.messageId + ' gNewestMessage is ' + gNewestMessage.messageId);
        successCallback(HistoryMessages);
    }, errorCallback);
}


  /**
   * 获取对话列表
   * @param {function} successCallback 成功获取后回调函数，定义为 .
   *        successCallback(HistoryMessages); HistoryMessages 是 {Object[]} json 对象数组
   * 包含的key 为：见头部消息定义
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function getNextCacheHistoryMessages(targetId, successCallback, errorCallback){
	var sql = 'SELECT * FROM ' + MESSAGES_TABLE_NAME + ' WHERE messageId < ' + gOldestMessage.messageId + "and targetId = '"+ targetId + "' ORDER BY messageId DESC LIMIT " + 50 + ';';
	selectSql(sql, function(HistoryMessages){
        for(var i = 0; i < HistoryMessages.length; i++) {
            var content = JSON.parse(HistoryMessages[i].content);
            HistoryMessages[i].content = content;
            HistoryMessages[i].sentTime = Number(HistoryMessages[i].sentTime);
            HistoryMessages[i].receivedTime = Number(HistoryMessages[i].receivedTime);
            //consoledebug.log('getCacheHistoryMessages i latestMessage.text is ' + HistoryMessages[i].latestMessage.text);
        }
        if(i > 0){
        	gOldestMessage = HistoryMessages[i-1];
        }
		consoledebug.log('getCacheHistoryMessages gOldestMessage is ' + gOldestMessage.messageId);
        successCallback(HistoryMessages);
    }, errorCallback);
}


function inertCacheHistoryMessagesPromis(messages) {
    var promise = new Bmob.Promise();

    var sql = "insert or replace into " + MESSAGES_TABLE_NAME + " (";
    var i = 0;
    var Values = "values(";
    if (messages.messageId) {
        Values += messages.messageId;
        sql += "messageId";
    }else{
        var err = {};
        err.code = 888;
        err.msg = "PRIMARY Key cannot be null";
        promise.reject(err);
        return;
    }
    if (messages.content) {
        Values += ", '" + JSON.stringify(messages.content) + "'";
        sql += ", content";
    }
    if (messages.conversationType) {
        Values += ", '" + messages.conversationType + "'";
        sql += ", conversationType";
    }
    if (messages.messageDirection) {
        Values += ", '" + messages.messageDirection + "'";
        sql += ", messageDirection";
    }
    if (messages.sentStatus) {
        Values += ", '" + messages.sentStatus + "'";
        sql += ", sentStatus";
    }
    if (messages.objectName) {
        Values += ", '" + messages.objectName + "'";
        sql += ", objectName";
    }
    if (messages.senderUserId) {
        Values += ", '" + messages.senderUserId + "'";
        sql += ", senderUserId";
    }
    if (messages.targetId) {
        Values += ", '" + messages.targetId + "'";
        sql += ", targetId";
    }
    if (messages.receivedTime) {
        Values += ", '" + messages.receivedTime + "'";
        sql += ", receivedTime";
    }
    if (messages.sentTime) {
        Values += ", '" + messages.sentTime + "'";
        sql += ", sentTime";
    }
    Values += ", '" + new Date().Format("yyyy-MM-dd hh:mm:ss") + "'";
    //Values += ", '2015-10-7 12:12:12'";
    sql += ", updateAt";
    
    sql += ") "
    Values += ");";
    sql += Values;
    insertSql(sql, function(){
        promise.resolve();
    }, function(err){
        promise.reject(err);
    });
    return promise;
}


  /**
   * 更新对话列表信息集合到本地缓存
   * @param {Object[]} HistoryMessages 用户对话列表 Json 对象数组
   * 包含的key 为：targetId, conversationTitle, conversationType, draft, latestMessage{text, extra}, sentStatus, objectName, recievedStatus, senderUserId, unreadMessageCount, receivedTime, sentTime, isTop, latestMessageId
   * @param {function} successCallback 成功插入列表后回调函数，定义为 .
   *        successCallback(); 
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function insertCacheHistoryMessages(HistoryMessages, successCallback, errorCallback){
	var promises = [];
	for (var i = 0; i < HistoryMessages.length; i++) {
		promises.push(inertCacheHistoryMessagesPromis(HistoryMessages[i]));
	}
	Bmob.Promise.when(promises).then(successCallback, errorCallback);
}

function removeMessage(messageId, successCallback, errorCallback){
    var sql = 'DELETE FROM ' + MESSAGES_TABLE_NAME + " WHERE messageId = " + messageId;
    updateSql(sql, successCallback, errorCallback);
}