var ORDERS_TABLE_NAME = "MyOrders";


/********************************* 字段说明 ***********************************
 * 
 *              orderID: String,        //订单ID
 *              orderName: String,        //订单名称
 *              classID: String,        //求助类别ID，为互助二级分类表中的ID
 *              beginTime: String,        //进行中界面显示的时间
 *              place: String,        //进行中界面显示的地址
 *              orderType: Number,     //订单类型，0为求助订单，1为活动订单，
 *              ownership: Number,        //当前用户与本订单的关系，0为求助人，1为帮助人，2为活动发起人，3为活动参与人
 *              state: Number,        //订单状态，根据 ownership 决定值的含义。
 * 									求助人：0 为关闭、1为选择帮助人，2为等待帮助完成、3验收帮助成果，4为等待评价，5为已完成通知，6为帮助人退出审核
 * 									帮助人：0为关闭，1为等待选帮助人、2未被选中通知、3帮助进行中、4等待验收、5结算处理，6完成通知，7帮助取消通知
 *                                  活动主办人：0为关闭，1为报名中，2为后付资金结算，3为等待收款，4为已收款，5为已完成，6为取消
 *                                  活动参与人：0为关闭，1报名中，2为未被选中，3为评价，4为后付资金结算，5为已完成，6为取消
 *              notify: Number,        //是否有更新通知，如果有，则显示通知标记， 0为无通知，1为有通知
 *              updateAt: String,        //最后更新时间
 */



function inertCacheOrdersPromis(orders) {
    var promise = new Bmob.Promise();

    var sql = "insert or replace into " + ORDERS_TABLE_NAME + " (";
    var i = 0;
    var Values = "values(";
    if (orders.hasOwnProperty('orderID')) {
        Values += orders.orderID;
        sql += "orderID";
    }else{
        var err = {};
        err.code = 888;
        err.msg = "PRIMARY Key cannot be null";
        promise.reject(err);
        return;
    }
    if (orders.hasOwnProperty('orderName')) {
        Values += ", '" + orders.orderName + "'";
        sql += ", orderName";
    }
    if (orders.hasOwnProperty('classID')) {
        Values += ", '" + orders.classID + "'";
        sql += ", classID";
    }
    if (orders.hasOwnProperty('beginTime')) {
        Values += ", '" + orders.beginTime + "'";
        sql += ", beginTime";
    }
    if (orders.hasOwnProperty('place')) {
        Values += ", '" + orders.place + "'";
        sql += ", place";
    }
    if (orders.hasOwnProperty('state')) {
        Values += ", " + orders.state;
        sql += ", state";
    }
    if (orders.hasOwnProperty('notify')) {
        Values += ", " + orders.notify;
        sql += ", notify";
    }
    if (orders.hasOwnProperty('ownership')) {
        Values += ", " + orders.ownership;
        sql += ", ownership";
    }
    if (orders.hasOwnProperty('orderType')) {
        Values += ", " + orders.orderType;
        sql += ", orderType";
    }
    Values += ", '" + new Date().Format("yyyy-MM-dd hh:mm:ss") + "'";
    //Values += ", '2015-10-7 12:12:12'";
    sql += ", updateAt";
    
    sql += ") "
    Values += ");";
    sql += Values;
    insertSql(sql, function(){
        promise.resolve();
    }, function(err){
        promise.reject(err);
    });
    return promise;
}


  /**
   * 更新任务订单到本地缓存
   * @param {Object[]} Historyorders 用户对话列表 Json 对象数组
   * 包含的key 为：orderID, orderName, classID, beginTime, place, state, notify, ownership, orderType, updateAt
   * @param {function} successCallback 成功插入列表后回调函数，定义为 .
   *        successCallback(); 
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function insertCacheOrders(orders, successCallback, errorCallback){
	var promise = new Bmob.Promise();
	if(!successCallback){
		successCallback = promise.resolve;
	}
	if(!errorCallback){
		errorCallback = promise.reject;
	}
    beginTrans(function(){
    	var promises = [];
        for(var i=0;i<orders.length;i++){
        	promises.push(inertCacheOrdersPromis(orders[i]));
        }
		Bmob.Promise.when(promises).then(function(){
        //promise.then(function(){
            commitTrans(function(){
                successCallback();
            },function(err){
                consoledebug.log('insertCacheOrders commitTrans error '+err.msg);
                errorCallback(err);
            });
        },function(err){
            commitTrans(function(){
                successCallback();
            },function(err){
                consoledebug.log('insertCacheOrders commitTrans error '+err.msg);
                errorCallback(err);
            });
            consoledebug.log('insertCacheOrders inertCacheHistoryordersPromis error '+err.msg);
            //errorCallback(err);
        });
    }, function(err){
        consoledebug.log('insertCacheOrders beginTrans error '+err.msg);
        errorCallback(err);
    });
}


function updateCacheOrderPromise(orders) {
    var promise = new Bmob.Promise();
    
    var sql = "update " + ORDERS_TABLE_NAME + " set ";
    var orderID = 0;
    var ordersType;
    var Values = "";
    if (orders.hasOwnProperty('orderID')) {
        orderID = orders.orderID;
        Values += "orderID = " + orders.orderID;
    }else{
        var err = {};
        err.code = 888;
        err.msg = "PRIMARY Key cannot be null";
        promise.reject(err);
        return;
    }
    if (orders.hasOwnProperty('orderName')) {
        Values += ", orderName = '" + orders.orderName + "'";
    }
    if (orders.hasOwnProperty('classID')) {
        Values += ", classID = '" + orders.classID + "'";
    }
    if (orders.hasOwnProperty('beginTime')) {
        Values += ", beginTime = '" + orders.beginTime + "'";
    }
    if (orders.hasOwnProperty('place')) {
        Values += ", place = '" + orders.place + "'";
    }
    if (orders.hasOwnProperty('state')) {
        Values += ", state = " + orders.state;
    }
    if (orders.hasOwnProperty('notify')) {
        Values += ", notify = " + orders.notify;
    }
    if (orders.hasOwnProperty('ownership')) {
        Values += ", ownership = " + orders.ownership;
    }
    if (orders.hasOwnProperty('orderType')) {
        Values += ", orderType = " + orders.orderType;
    }
    Values += ", updateAt = '" + new Date().Format("yyyy-MM-dd hh:mm:ss") + "'";
    sql += Values + " WHERE orderID = " + orderID;
    updateSql(sql, function(){
        promise.resolve();
    }, function(err){
        consoledebug.log('updateCacheordersPromise updateSql error is ' + err.msg);
        promise.reject(err);
    });
    return promise;
}


  /**
   * 更新缓存中的我的进行中任务订单列表
   * @param {Object[]} ordersList 需要更新的任务订单列表
   * 包含的key 为：orderID, orderName, classID, beginTime, place, state, notify, ownership, orderType, updateAt
   * @param {function} successCallback 成功插入列表后回调函数，定义为 .
   *        successCallback(); 
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function updateCacheMyOrders(ordersList){
	var promise = new Bmob.Promise();
    beginTrans(function(){
    	var promises = [];
        for(var i=0;i<ordersList.length;i++){
        	promises.push(updateCacheOrderPromise(ordersList[i]));
        }
		Bmob.Promise.when(promises).then(function(){
        //promise.then(function(){
            commitTrans(function(){
                promise.resolve();
            },function(err){
                consoledebug.log('updateCacheMyOrders commitTrans error '+err.msg);
                promise.reject(err);
            });
        },function(err){
            commitTrans(function(){
                promise.resolve();
            },function(err){
                consoledebug.log('updateCacheMyOrders commitTrans error '+err.msg);
                promise.reject(err);
            });
            consoledebug.log('updateCacheMyOrders updateCacheOrderPromise error '+err.msg);
            //errorCallback(err);
        });
    }, function(err){
        consoledebug.log('updateCacheMyOrders beginTrans error '+err.msg);
        promise.reject(err);
    });
    return promise;
}


  /**
   * 获取对话列表
   * @param {function} successCallback 成功获取后回调函数，定义为 .
   *        successCallback(orders); orders 是 {Object[]} json 对象数组
   * 包含的key 为：见头部消息定义
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function getCacheOrders(successCallback, errorCallback){
    var	sql = 'SELECT * FROM ' + ORDERS_TABLE_NAME + " ORDER BY updateAt DESC ;";
    selectSql(sql, function(orders){
        for(var i = 0; i < orders.length; i++) {
            orders[i].state = Number(orders[i].state);
            orders[i].notify = Number(orders[i].notify);
            orders[i].ownership = Number(orders[i].ownership);
            orders[i].orderType = Number(orders[i].orderType);
            //consoledebug.log('getCacheorders i latestMessage.text is ' + orders[i].latestMessage.text);
        }
        successCallback(orders);
    }, errorCallback);
}

function getCacheTypeOrders(orderType, successCallback, errorCallback){
	var promise = new Bmob.Promise();
    var	sql = 'SELECT * FROM ' + ORDERS_TABLE_NAME + " WHERE orderType = " + orderType + " ORDER BY updateAt DESC ;";
    selectSql(sql, function(orders){
    	var orderMap = [];
        for(var i = 0; i < orders.length; i++) {
            orders[i].state = Number(orders[i].state);
            orders[i].notify = Number(orders[i].notify);
            orders[i].ownership = Number(orders[i].ownership);
            orders[i].orderType = Number(orders[i].orderType);
            orderMap[orders[i].orderID] = orders[i];
            //consoledebug.log('getCacheorders i latestMessage.text is ' + orders[i].latestMessage.text);
        }
        if(successCallback){
        	successCallback(orders);
        }else{
        	promise.resolve(orderMap);
        }
    }, function(err){
    	if(errorCallback){
    		errorCallback(err);
    	}else{
        	promise.reject(err);
    	}
    });
    return promise;
}

  /**
   * 获取对话列表
   * @param {function} successCallback 成功获取后回调函数，定义为 .
   *        successCallback(orders); orders 是 {Object[]} json 对象数组
   * 包含的key 为：见头部消息定义
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function getOneCacheOrder(orderID, successCallback, errorCallback){
    var sql = 'SELECT * FROM ' + ORDERS_TABLE_NAME + " WHERE orderID = " + orderID;
    selectSql(sql, function(orders){
        if(orders.length > 0){
            orders[0].state = Number(orders[0].state);
            orders[0].notify = Number(orders[0].notify);
            orders[0].ownership = Number(orders[0].ownership);
            orders[0].orderType = Number(orders[0].orderType);
        	successCallback(orders[0]);
        }else{
        	errorCallback();
        }
    }, errorCallback);
}

  /**
   * 获取我发布的正在报名中的订单
   * @param {function} successCallback 成功获取后回调函数，定义为 .
   *        successCallback(orders); orders 是 {Object[]} json 对象数组
   * 包含的key 为：见头部消息定义
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, msg:string}
   */
function getCacheMyInviteOrders(successCallback, errorCallback){
    var	sql = 'SELECT * FROM ' + ORDERS_TABLE_NAME + " WHERE ownership = 0 AND state = 1 ORDER BY updateAt DESC ;";
    selectSql(sql, function(orders){
        for(var i = 0; i < orders.length; i++) {
            orders[i].state = Number(orders[i].state);
            orders[i].notify = Number(orders[i].notify);
            orders[i].ownership = Number(orders[i].ownership);
            orders[i].orderType = Number(orders[i].orderType);
            //consoledebug.log('getCacheorders i latestMessage.text is ' + orders[i].latestMessage.text);
        }
        successCallback(orders);
    }, errorCallback);
}

function deleteCacheOrder(orderID, orderType, successCallback, errorCallback){
    var sql = 'DELETE FROM ' + ORDERS_TABLE_NAME + " WHERE orderID = " + orderID + ' AND orderType = ' + orderType;
    updateSql(sql, successCallback, errorCallback);
}

function getEarliestUpdatetimeCacheOrder(successCallback, errorCallback){
    var sql = 'SELECT updateAt FROM ' + ORDERS_TABLE_NAME + " ORDER BY updateAt ASC LIMIT 1;";
    selectSql(sql, function(time){
    	//格式 ：[{"max(updateAt)":""}]
    	consoledebug.log('getEarliestUpdatetimeCacheOrder time is ' + JSON.stringify(time));
        
        var earliestTime;
        if(time.length > 0){
        	earliestTime = time[0].updateAt;
        }
        successCallback(earliestTime);
    }, function(err){
    	consoledebug.log('getEarliestUpdatetimeCacheOrder err is ' + JSON.stringify(err));
    	errorCallback(err)
    });
}


function setUpdatetimeCacheOrder(strNowDate, successCallback, errorCallback){
    var sql = 'update ' + ORDERS_TABLE_NAME + " set updateAt = '" + strNowDate + "'";
    updateSql(sql, function(){
        successCallback();
    }, errorCallback);
}

//设置未读标记，并将任务置顶
function setUnreadCacheOrder(orderID, orderType, successCallback, errorCallback){
    var sql = 'update ' + ORDERS_TABLE_NAME + " set notify = 1, updateAt = '" + new Date().Format("yyyy-MM-dd hh:mm:ss") + "' WHERE orderID = " + orderID + ' AND orderType = ' + orderType;
    updateSql(sql, function(){
        api.execScript({
            name : 'root',
            script : 'setWayingUnreadCount()'
        });
        successCallback();
    }, errorCallback);
}

//同步任务状态
function syncCacheOrderState(orderID, orderType, state, successCallback, errorCallback){
    var sql = 'update ' + ORDERS_TABLE_NAME + " set state = " + state + " WHERE orderID = " + orderID + ' AND orderType = ' + orderType;
    updateSql(sql, successCallback, errorCallback);
}

//设置未读标记，并将任务置顶
function setCacheOrderNewState(orderID, orderType, state, successCallback, errorCallback){
    var sql = 'update ' + ORDERS_TABLE_NAME + " set notify = 1, state = " + state + ", updateAt = '" + new Date().Format("yyyy-MM-dd hh:mm:ss") + "' WHERE orderID = " + orderID + ' AND orderType = ' + orderType;
    updateSql(sql, function(){
        api.execScript({
            name : 'root',
            script : 'setWayingUnreadCount()'
        });
        successCallback();
    }, errorCallback);
}

//清除未读标记，任务在列表中的位置不变
function clearUnreadCacheOrder(orderID, orderType, successCallback, errorCallback){
    var sql = 'update ' + ORDERS_TABLE_NAME + ' set notify = 0 WHERE orderID = ' + orderID + ' AND orderType = ' + orderType;
    updateSql(sql, successCallback, errorCallback);
}

//获取未读订单的数量
function getUnreadCacheOrderCount(successCallback, errorCallback){
    var sql = 'SELECT orderID FROM ' + ORDERS_TABLE_NAME + " WHERE notify = 1;";
    selectSql(sql, function(orders){
        successCallback(orders.length);
    }, errorCallback);
}

