  /**
   * 获取朋友列表
   * 
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(friends); friends 是 {Bmob.Object} 类数组，通过friends[x].get(key) 可获取值，
   * 		可用的 key 有 "friendID", "state", "reason"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function getMyFriends(successCallback, errorCallback){
    var myAcount = getMyAccount();
	if (myAcount) {
		var Table = Bmob.Object.extend("MyFriends");
		var query = new Bmob.Query(Table);
		query.equalTo("userID", myAcount.hhID);
		// 查询所有数据
		query.find({
		    success: function(results) {
                successCallback(results);
		    },
		    error: function(error) {
		        //alert("查询失败: " + error.code + " " + error.message);
		        //api.toast({msg: error.message, location: 'middle'});
		        errorCallback(error);
		    }
		});
	}
}

  /**
   * 将朋友添加到通讯录
   *
   * @param {Number} friendID 要加的好友的 hhID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   *        successCallback(friend); friend 是 {Bmob.Object} 类，通过 friend.get(key) 可获取值，
   *        可用的 key 有 "friendID", "state", "reason"
   *        state 值为0表示已经是朋友，1表示对方申请加好友，3表示我正申请加对方为好友
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, message:string}
   */
function addToFriendBook(friendID, successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          var MyFriends = Bmob.Object.extend("MyFriends");
          var myFriends = new MyFriends();
          myFriends.set("userID", myAcount.hhID);
          myFriends.set("friendID", friendID);
          myFriends.set("state", 0);
          myFriends.set("reason", "添加通讯录");
          myFriends.set("relation", 1);
          myFriends.save().then(successCallback, errorCallback);
      }
}

function isFriend(friendID, successCallback, errorCallback){
    var myAcount = getMyAccount();
	if (myAcount) {
		var Table = Bmob.Object.extend("MyFriends");
		var query = new Bmob.Query(Table);
		query.equalTo("userID", myAcount.hhID);
		query.equalTo("friendID", friendID);
		// 查询所有数据
		query.count().then(function(count){
			if(count > 0){
				successCallback(true);
			}else{
				successCallback(false);
			}
		},function(error){
			errorCallback(error);
		});
	}
}

  /**
   * 获取朋友的详细信息
   *
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(usersInfo); usersInfo 是 {Bmob.Object} 对象数组，通过 usersInfo[x].get(key) 可获取值，
   * 		可用的 key 有 "hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime"
   * 		其中，photo 是 file 类， 其  url 的获取方式为： usersInfo[x].get('photo')._url
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function getFriendInfo(successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          var MyFriends = Bmob.Object.extend("MyFriends");
          var myFriendsQuery = new Bmob.Query(MyFriends);
          myFriendsQuery.equalTo("userID", myAcount.hhID);
          var Table = Bmob.Object.extend("UserInfo");
          var query = new Bmob.Query(Table);
          query.matchesKeyInQuery("hhID", "friendID", myFriendsQuery);
          query.select("hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime");
          query.ascending("nickName");
          query.find({
              success: function(results) {
                  successCallback(results);
              },
              error: function(error) {
                  //alert("查询失败: " + error.code + " " + error.message);
                  //api.toast({msg: error.message, location: 'middle'});
                  errorCallback(error);
              }
          });
      }
  }

  /**
   * 获取群成员的详细信息
   *
   * @param {Number} groupID: 群ID
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(usersInfo); usersInfo 是 {Bmob.Object} 对象数组，通过 usersInfo[x].get(key) 可获取值，
   * 		可用的 key 有"hhID",  "nickName", "sex", "level", "age", "photo", "location", "onlineTime"
   * 		其中，photo 是 file 类， 其  url 的获取方式为： usersInfo[x].get('photo')._url
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function getGroupMemberInfo(groupID, successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          var GroupMembers = Bmob.Object.extend("GroupMembers");
          var groupMembersQuery = new Bmob.Query(GroupMembers);
          groupMembersQuery.equalTo("groupID", groupID);
          groupMembersQuery.descending("updatedAt");
//        var Table = Bmob.Object.extend("UserInfo");
//        var query = new Bmob.Query(Table);
//        query.matchesKeyInQuery("hhID", "hhID", groupMembersQuery);
//		  query.notEqualTo("hhID", builderHHID);
          groupMembersQuery.include("userInfo");
          groupMembersQuery.select("hhID", "nickname", "userInfo", "location", "onlineTime");
          groupMembersQuery.find({
              success: function(results) {
                  successCallback(results);
              },
              error: function(error) {
                  //alert("查询失败: " + error.code + " " + error.message);
                  //api.toast({msg: error.message, location: 'middle'});
                  errorCallback(error);
              }
          });
      }
  }

function getGroupMembersInfo(groupID, successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          var GroupMembers = Bmob.Object.extend("GroupMembers");
          var query = new Bmob.Query(GroupMembers);
          query.equalTo("groupID", groupID);
          query.ascending("updatedAt");
          query.select("hhID", "groupID","nickname", "joinTime", "state", "status", "noDisturb");
          query.find({
              success: function(results) {
                  successCallback(results);
              },
              error: function(error) {
                  //alert("查询失败: " + error.code + " " + error.message);
                  //api.toast({msg: error.message, location: 'middle'});
                  errorCallback(error);
              }
          });
      }
  }

  /**
   * 获取群列表
   * 
   * @param {function} successCallback 成功获取群列表后回调函数，定义为 .
   * 		successCallback(groups); groups 是 {Bmob.Object} 类数组，通过 groups[x].get(key) 可获取值，
   * 		可用的 key 有 "groupID", "groupName", "rongyunID", "buildTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function getMygroups(successCallback, errorCallback){
      var myAcount = getMyAccount();
	if (myAcount) {
        var Group = Bmob.Object.extend("GroupMembers");
        var groupQuery = new Bmob.Query(Group);
        groupQuery.equalTo("hhID", myAcount.hhID);
        groupQuery.equalTo("state", 0);
        var Table = Bmob.Object.extend("Group");
        var query = new Bmob.Query(Table);
        query.matchesKeyInQuery("groupID", "groupID", groupQuery);
        query.descending("updatedAt");
        query.find({
            success: function(results) {
                successCallback(results);
            },
            error: function(error) {
                //alert("查询失败: " + error.code + " " + error.message);
                //api.toast({msg: error.message, location: 'middle'});
                errorCallback(error);
            }
        });
	}
}

  /**
   * 获取群列表
   *
   * @param {Number} groupID: 群ID
   * @param {function} successCallback 成功获取群列表后回调函数，定义为 .
   * 		successCallback(members); members 是 {Bmob.Object} 类数组，通过 members[x].get(key) 可获取值，
   * 		可用的 key 有 "hhID", "groupID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function getGroupMembers(groupID, successCallback, errorCallback) {
	var Table = Bmob.Object.extend("GroupMembers");
	var query = new Bmob.Query(Table);
	query.equalTo("groupID", groupID);
	// 查询所有数据
	query.find({
		success : function(results) {
            successCallback(results);
		},
		error : function(error) {
			//alert("查询失败: " + error.code + " " + error.message);
			//api.toast({msg: error.message, location: 'middle'});
			errorCallback(error);
		}
	});
}

  /**
   * 获取用户信息, 可用于获取朋友信息，组成员信息
   * @param {Bmob.Object[]} users 包含用户ID(hhID) 的对象数组
   * @param {String} userIDName: users 中用户ID字段的名字
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(usersInfo); usersInfo 是 {Bmob.Object} 对象数组，通过 usersInfo[x].get(key) 可获取值，
   * 		可用的 key 有 "hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime"
   * 		其中，photo 是 file 类， 其  url 的获取方式为： usersInfo[x].get('photo')._url
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function getUsersInfo(users, userIDName, successCallback, errorCallback) {
	var Table = Bmob.Object.extend("UserInfo");
	var query = new Bmob.Query(Table);
	var hhIDArray = [];
	for(var i = 0; i<users.length; i++) {
		hhIDArray.push(users[i].get(userIDName));
	}
	query.containedIn("hhID", hhIDArray);
	query.select("hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime");
	// 查询所有数据
	query.find({
		success : function(results) {
			successCallback(results);
		},
		error : function(error) {
			//alert("查询失败: " + error.code + " " + error.message);
			//api.toast({msg: error.message, location: 'middle'});
			errorCallback(error);
		}
	});
}

	//获取朋友列表
	function getInvitedFriends(groupID, successCallback, errorCallback) {
		var myAcount = getMyAccount();
		if (myAcount) {
			// 查询所有数据
			var GroupMembers = Bmob.Object.extend("GroupMembers");
			var groupMembersQuery = new Bmob.Query(GroupMembers);
			groupMembersQuery.equalTo("groupID", groupID);
			groupMembersQuery.ascending("updatedAt");
			
			var Table = Bmob.Object.extend("MyFriends");
			var friendsQuery = new Bmob.Query(Table);
			friendsQuery.equalTo("userID", myAcount.hhID);
			friendsQuery.doesNotMatchKeyInQuery("friendID", "hhID", groupMembersQuery);
			
			var Table = Bmob.Object.extend("UserInfo");
			var query = new Bmob.Query(Table);
			query.matchesKeyInQuery("hhID", "friendID", friendsQuery);
			query.select("hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime");
			query.find({
				success : function(results) {
					successCallback(results);
				},
				error : function(error) {
					//alert("查询失败: " + error.code + " " + error.message);
					//api.toast({msg: error.message, location: 'middle'});
					errorCallback(error);
				}
			});
		}
	}
	
	
  /**
   * 获取自己的信息
   *
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(myInfo); myInfo 是 {Bmob.Object} 对象，通过 myInfo.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime"
   * 		其中，photo 是 file 类， 其  url 的获取方式为： myInfo.get('photo')._url
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function getMyInfo(successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          var Table = Bmob.Object.extend("UserInfo");
          var query = new Bmob.Query(Table);
          query.equalTo("hhID", myAcount.hhID);
          query.select("hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime");
          // 查询所有数据
          query.find({
              success : function(results) {
                  if(results.length > 0){
                      successCallback(results[0]);
                  }else{
                      var err = new Object();
                      err.code = 702;
                      err.message = "No hhID UserInfo";
                      errorCallback(err);
                  }
              },
              error : function(error) {
                  //alert("查询失败: " + error.code + " " + error.message);
                  //api.toast({msg: error.message, location: 'middle'});
                  errorCallback(error);
              }
          });
      }
  }

  /**
   * 获取用户信息, 可用于获取朋友信息，组成员信息
   * @param {Number} hhID 用户ID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(Nickname); Nickname 是 {String} 用户名字符串
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function getNickname(hhID, successCallback, errorCallback) {
      var Table = Bmob.Object.extend("UserInfo");
      var query = new Bmob.Query(Table);
      query.equalTo("hhID", hhID);
      query.select("nickName");
      // 查询所有数据
      query.find({
          success : function(results) {
              if(results.length > 0){
                  successCallback(results[0]);
              }else{
                  var err = new Object();
                  err.code = 702;
                  err.message = "No hhID UserInfo";
                  errorCallback (err);
              }
          },
          error : function(error) {
              //alert("查询失败: " + error.code + " " + error.message);
              //api.toast({msg: error.message, location: 'middle'});
              errorCallback(error);
          }
      });
  }

  /**
   * 根据用户昵称查找 hhID
   *
   * @param {String} nickname 用户昵称
   * @param {function} successCallback 查找所有跟用户昵称匹配的用户列表，定义为 .
   * 		successCallback(UserInfo); UserInfo 是 {Bmob.Object} 类对象数组，通过 UserInfo[x].get(key) 可获取值，
   * 		可用的 key 有 "hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function findHhID(nickname, successCallback, errorCallback){
      var Table = Bmob.Object.extend("UserInfo");
      var query = new Bmob.Query(Table);
      query.equalTo("nickName", nickname);
      query.select("hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime");
      // 查询所有数据
      query.find({
          success : function(results) {
              successCallback(results);
          },
          error : function(error) {
              //alert("查询失败: " + error.code + " " + error.message);
              //api.toast({msg: error.message, location: 'middle'});
              errorCallback(error);
          }
      });
  }

  /**
   * 获取组名
   * @param {Number} groupID 组ID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(groupInfo); groupInfo 是 {Bmob.Object} 类对象，通过 groupInfo.get(key) 可获取值，
   * 		可用的 key 有 "groupID", "groupName", "rongyunID", "buildTime", "avatar"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function getGroupInfo(groupID, successCallback, errorCallback) {
  	  groupID = Number(groupID);
      var Table = Bmob.Object.extend("Group");
      var query = new Bmob.Query(Table);
      query.equalTo("groupID", groupID);
      // 查询所有数据
      query.find({
          success : function(results) {
              if(results.length > 0){
                  successCallback(results[0]);
              }else{
                  var err = new Object();
                  err.code = 705;
                  err.message = "No groupID groupInfo";
                  errorCallback (err);
              }
          },
          error : function(error) {
              //alert("查询失败: " + error.code + " " + error.message);
              //api.toast({msg: error.message, location: 'middle'});
              errorCallback(error);
          }
      });
  }

  /**
   * 获取用户信息集合
   *
   * @param {Number[]} rongyunIDs: 存储要查询的群信息的 rongyunID 数组
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(groupInfos); groupInfos 是 {Object[]} 对象数组，
   * 		单个数组元素的定义见 getGroupInfo 方法
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(error); error is a class, {code: number, message:string}
   */

function getNetGroupInfos(rongyunIDs, successCallback, errorCallback) {
	var err = {};
    if (rongyunIDs.length < 1) {
        err.code = 888;
        err.message = "length cannot be 0";
        errorCallback(err);
        return;
    }
    if(typeof rongyunIDs[0] != 'string'){
        consoledebug.log('error getNetGroupInfos rongyunIDs is not string' + typeof rongyunIDs[0]);
        err.code = 888;
        err.message = "rongyunID type is not string";
        errorCallback(err);
        return;
    }
    var GroupInfo = Bmob.Object.extend("Group");
    var query = new Bmob.Query(GroupInfo);
    query.containedIn("rongyunID", rongyunIDs);
    // 查询所有数据
    query.find({
        success : function(results) {
            // 循环处理查询到的数据
            if (results.length > 0) {
                successCallback(results);
            } else {
                var err = {};
                err.code = 888;
                err.message = "length is 0";
                errorCallback(err);
            }
        },
        error : function(error) {
            errorCallback(error);
        }
    });
}

  /**
   * 获取组名
   * @param {String} rongyunID 融云组ID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(groupInfo); groupInfo 是 {Bmob.Object} 类对象，通过 groupInfo.get(key) 可获取值，
   * 		可用的 key 有 "groupID", "groupName", "rongyunID", "buildTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function getGroupInfoByRyid(rongyunID, successCallback, errorCallback) {
      consoledebug.log('getGroupInfoByRyid rongyunID is ' + rongyunID);
      var Table = Bmob.Object.extend("Group");
      var query = new Bmob.Query(Table);
      query.equalTo("rongyunID", rongyunID);
      // 查询所有数据
      query.find({
          success : function(results) {
              if(results.length > 0){
                  successCallback(results[0]);
              }else{
                  var err = new Object();
                  err.code = 706;
                  err.message = "No rongyunID groupInfo";
                  errorCallback (err);
              }
          },
          error : function(error) {
              //alert("查询失败: " + error.code + " " + error.message);
              //api.toast({msg: error.message, location: 'middle'});
              errorCallback(error);
          }
      });
  }


  /**
   * 获取用户集合的头像
   *
   * @param {Object[]} avatarObjs: 要查询的用户集合信息，
   * 		包含的 属性有： {Number} rongyunID, {String} url
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(avatarArray); avatarArray 是 {Object[]} 对象数组，
   * 		包含的 属性有： {Number} rongyunID, {String} photo
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(); }
   */
function getGroupAvatarArray(avatarObjs, successCallback, errorCallback) {

	var avatarArray = new Array(avatarObjs.length);
	//var promise = Bmob.Promise.as();
	var i = 0;
	var promises = [];
	for (var i = 0; i < avatarObjs.length; i++) {
		avatarArray[i] = {};
		avatarArray[i].rongyunID = avatarObjs[i].rongyunID;
		promises.push(getAvatarThumbnail(avatarObjs[i].url, avatarArray[i]));
	}
//	$.each(avatarObjs, function() {
//		var avatarObj = this;
//		avatarArray[i] = new Object();
//		avatarArray[i].rongyunID = avatarObj.rongyunID;
//		var thuPromise = getAvatarThumbnail(avatarObj.url, avatarArray[i]);
//		i++;
//		promises.push(thuPromise);
//	});
	var alldone = Bmob.Promise.when(promises);
	alldone.then(function (){
		successCallback(avatarArray);
	}, function(){
		errorCallback();
	});
}


  /**
   * 获取请求加朋友列表
   * 
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(friends); friends 是 {Bmob.Object} 类数组，通过friends[x].get(key) 可获取值，
   * 		可用的 key 有 "friendID", "state", "reason"
   * 		另外可通过 friends[x].id 获取当前请求ID
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function getAddFriends(successCallback, errorCallback){
      var myAcount = getMyAccount();
	if (myAcount) {
		var Table = Bmob.Object.extend("MyFriends");
		var query = new Bmob.Query(Table);
		query.equalTo("userID", myAcount.hhID); 
		query.equalTo("state", 1);
        query.descending("updatedAt");
		// 查询所有数据
		query.find({
		    success: function(results) {
                successCallback(results);
		    },
		    error: function(error) {
		        //alert("查询失败: " + error.code + " " + error.message);
		        //api.toast({msg: error.message, location: 'middle'});
		        errorCallback(error);
		    }
		});
	}
}

/**
   * 获取请求加群列表
   * 
   * @param {function} successCallback 成功获取群列表后回调函数，定义为 .
   * 		successCallback(groups); groups 是 {Bmob.Object} 类数组，通过 groups[x].get(key) 可获取值，
   * 		可用的 key 有 "groupID", "hhID", "state", "reason"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
*/
function getAddgroups(successCallback, errorCallback){
      var myAcount = getMyAccount();
	if (myAcount) {
        var Group = Bmob.Object.extend("Group");
        var groupQuery = new Bmob.Query(Group);
        groupQuery.equalTo("builderHHID", myAcount.hhID);
        var Table = Bmob.Object.extend("GroupMembers");
        var query = new Bmob.Query(Table);
        query.matchesKeyInQuery("groupID", "groupID", groupQuery);
        query.equalTo("state", 1);
        query.descending("updatedAt");
        query.find({
            success: function(results) {
                successCallback(results);
            },
            error: function(error) {
                //alert("查询失败: " + error.code + " " + error.message);
                //api.toast({msg: error.message, location: 'middle'});
                errorCallback(error);
            }
        });
	}
}

  /**
   * 申请加对方为好友
   * 
   * @param {Number} friendID 要加的好友的 hhID
   * @param {String} reason 申请理由
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(friend); friend 是 {Bmob.Object} 类，通过 friend.get(key) 可获取值，
   * 		可用的 key 有 "friendID", "state", "reason"
   * 	    state 值为0表示已经是朋友，1表示对方申请加好友，3表示我正申请加对方为好友
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function applyAddFriends(friendID, reason, successCallback, errorCallback){
      var myAcount = getMyAccount();
	if (myAcount) {
		var MyFriends = Bmob.Object.extend("MyFriends");
		var myFriends = new MyFriends();
		myFriends.set("userID", myAcount.hhID);
		myFriends.set("friendID", friendID);
		myFriends.set("state", 3);
		myFriends.set("reason", reason);
		//添加数据，第一个入口参数是null
		myFriends.save().then(function(myFriends) {	
			var myFriends2 = new MyFriends();
			myFriends2.set("userID", friendID);
			myFriends2.set("friendID", myAcount.hhID);
			myFriends2.set("state", 1);
			myFriends2.set("reason", reason);
			return myFriends2.save();
		}).then(successCallback, errorCallback);
	}
}

  /**
   * 直接加对方为好友。供系统自动加好友功能调用
   *
   * @param {Number} friendID 要加的好友的 hhID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(friend); friend 是 {Bmob.Object} 类，通过 friend.get(key) 可获取值，
   * 		可用的 key 有 "friendID", "state", "reason"
   * 	    state 值为0表示已经是朋友，1表示对方申请加好友，3表示我正申请加对方为好友
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function makeFriends(friendID, successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          var MyFriends = Bmob.Object.extend("MyFriends");
          var myFriends = new MyFriends();
          myFriends.set("userID", myAcount.hhID);
          myFriends.set("friendID", friendID);
          myFriends.set("state", 0);
          myFriends.set("reason", "系统添加");
          //添加数据，第一个入口参数是null
          myFriends.save().then(function(myFriends) {
              var myFriends2 = new MyFriends();
              myFriends2.set("userID", friendID);
              myFriends2.set("friendID", myAcount.hhID);
              myFriends2.set("state", 0);
              myFriends2.set("reason", "系统添加");
              return myFriends2.save();
          }).then(successCallback, errorCallback);
      }
  }

  /**
   * 同意对方加好友申请
   * 
   * @param {String} applyID 加好友申请的 ID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback(friend); friends 是 {Bmob.Object} 类，通过 friend.get(key) 可获取值，
   * 		可用的 key 有 "friendID", "state", "reason"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function agreeAddFriends(applyID, successCallback, errorCallback){
      var myAcount = getMyAccount();
	if (myAcount) {
		var MyFriends = Bmob.Object.extend("MyFriends");
		var query = new Bmob.Query(MyFriends);
		//查询单条数据，第一个参数是这条数据的objectId值
		query.get(applyID, {
		success: function(myFriend){
			myFriend.set("state", 0);
			myFriend.save().then(function(myFriend){
				var Table = Bmob.Object.extend("MyFriends");
				var query = new Bmob.Query(Table);
				query.equalTo("userID", myFriend.get("friendID")); 
				query.equalTo("friendID", myFriend.get("userID")); 
				// 查询所有数据
				return query.find();
			}).then(function(myFriends){
				myFriends[0].set("state", 0);
				return myFriends[0].save();
			}).then(successCallback, errorCallback);
		},
		error: errorCallback
		});
	}
}

  /**
   * 删除好友
   *
   * @param {Number} friendID 删除好友的 ID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback();
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function removeFriend(friendID, successCallback, errorCallback) {
	var promises = [];
	var myAcount = getMyAccount();
	if (myAcount) {
		var Table = Bmob.Object.extend("MyFriends");
		var query = new Bmob.Query(Table);
		query.equalTo("userID", myAcount.hhID);
		query.equalTo("friendID", friendID);

		var Table2 = Bmob.Object.extend("MyFriends");
		var query2 = new Bmob.Query(Table2);
		query2.equalTo("userID", friendID);
		query2.equalTo("friendID", myAcount.hhID);

		promises.push(query.find());
		promises.push(query2.find());
		Bmob.Promise.when(promises).then(function(myFriends, hisFriends){
			var promises2 = [];
			if (myFriends.length > 0) {
				promises2.push(myFriends[0].destroy());
			}
			if (hisFriends.length > 0) {
				promises2.push(hisFriends[0].destroy());
			}
			Bmob.Promise.when(promises).then(successCallback, errorCallback);
		}, errorCallback);
	}
}

function unattentionFriend(friendID, successCallback, errorCallback) {
	var promises = [];
	var myAcount = getMyAccount();
	if (myAcount) {
		var Table = Bmob.Object.extend("MyFriends");
		var query = new Bmob.Query(Table);
		if(myAcount.hhID && friendID){
			query.equalTo("userID", myAcount.hhID);
			query.equalTo("friendID", friendID);
			query.destroyAll().then(successCallback, errorCallback);
		}else{
			errorCallback();
		}
	}
}


  /**
   * 加群申请
   *
   * @param {Number} groupID 群ID
   * @param {String} reason 申请理由
   * @param {function} successCallback 成功发送申请后回调函数，定义为 .
   * 		successCallback(groupMember); groupMember 是 {Bmob.Object} 类，通过 groupMember.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function joinGroupApply(groupID, reason, successCallback, errorCallback){
      var myAcount = getMyAccount();
      if (myAcount) {
          getNickname(myAcount.hhID, function (userInfo) {
              var GroupMembers = Bmob.Object.extend("GroupMembers");
              var groupMembers = new GroupMembers();
              groupMembers.set("hhID", myAcount.hhID);
              groupMembers.set("groupID", groupID);
              groupMembers.set("nickname", userInfo.get("nickName"));
              groupMembers.set("state", 1);
              groupMembers.set("reason", reason);
              groupMembers.set("joinTime", new Date());
              groupMembers.set("noDisturb", false);
              groupMembers.set("status", 1);
              groupMembers.set("userInfo", userInfo);
              //添加数据，第一个入口参数是null
              groupMembers.save().then(successCallback, errorCallback);
          },errorCallback);
      }
  }

  /**
   * 群主主动拉人入群
   *
   * @param {Number} groupID 群ID
   * @param {Number} hhID 加群申请人ID
   * @param {function} successCallback 成功拉人入群后回调函数，定义为 .
   * 		successCallback(groupMember); groupMember 是 {Bmob.Object} 类，通过 groupMember.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "groupID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function addGroupMember(groupID, hhID, successCallback, errorCallback){
      authorityCheck(groupID, function (group) {
          var status = (hhID === group.get("builderHHID")) ? 0 : 1;
          getNickname(hhID, function (userInfo) {
              var GroupMembers = Bmob.Object.extend("GroupMembers");
              var groupMembers = new GroupMembers();
              groupMembers.set("hhID", hhID);
              groupMembers.set("groupID", groupID);
              groupMembers.set("nickname", userInfo.get("nickName"));
              groupMembers.set("state", 0);
              groupMembers.set("reason", "群主拉入");
              groupMembers.set("joinTime", new Date());
              groupMembers.set("noDisturb", false);
              groupMembers.set("status", status);
              groupMembers.set("userInfo", userInfo);
              //添加数据，第一个入口参数是null
              groupMembers.save().then(successCallback, errorCallback);
          },errorCallback);
      },errorCallback);
  }
  

function systemAddGroupMember(group, hhID, successCallback, errorCallback) {
	var status = (hhID === group.get("builderHHID")) ? 0 : 1;
	getNickname(hhID, function(userInfo) {
		var GroupMembers = Bmob.Object.extend("GroupMembers");
		var groupMembers = new GroupMembers();
		groupMembers.set("hhID", hhID);
		groupMembers.set("groupID", group.get("groupID"));
		groupMembers.set("nickname", userInfo.get("nickName"));
		groupMembers.set("state", 0);
		groupMembers.set("reason", "群主拉入");
		groupMembers.set("joinTime", new Date());
		groupMembers.set("noDisturb", false);
		groupMembers.set("status", status);
		groupMembers.set("userInfo", userInfo);
		//添加数据，第一个入口参数是null
		groupMembers.save().then(successCallback, errorCallback);
	}, errorCallback);
}
//帮助人取消帮助后，需要有退群的功能
function systemQuitGroupMember(groupID, ownerID, successCallback, errorCallback){
	var GroupMembers = Bmob.Object.extend("GroupMembers");
    var query = new Bmob.Query(GroupMembers);
    query.equalTo("groupID",groupID);
    query.equalTo("hhID",ownerID);
    query.destroyAll({
		success : function() {
            successCallback();
		},
		error : function(error) {
			consoledebug.log('deleteHelpOrder HelpOrder error is '+ JSON.stringify(error));
            errorCallback(error);
		}
	});
}
  
function addGroupMembersPromise(groupID, hhID) {
	var promise = new Bmob.Promise();
	var Table = Bmob.Object.extend("UserInfo");
	var query = new Bmob.Query(Table);
	query.equalTo("hhID", Number(hhID));
	query.select("nickName", "hhID");
	// 查询所有数据
	query.find().then(function(userInfo) {
		if(userInfo.length > 0){
			var GroupMembers = Bmob.Object.extend("GroupMembers");
			var groupMembers = new GroupMembers();
			groupMembers.set("hhID", userInfo[0].get("hhID"));
			groupMembers.set("groupID", groupID);
			groupMembers.set("nickname", userInfo[0].get("nickName"));
			groupMembers.set("state", 0);
			groupMembers.set("reason", "群主拉入");
			groupMembers.set("joinTime", new Date());
			groupMembers.set("noDisturb", false);
			groupMembers.set("status", 1);
			groupMembers.set("userInfo", userInfo[0]);
			groupMembers.save().then(function() {
	        	promise.resolve();
			}, function(error) {
	        	promise.reject(error);
			})
		}else {
			var error = {
				code: 888,
				message: 'no record. '
			}
	     	promise.reject(error);
		}
	}, function(error) {
        promise.reject(error);
	})
	
	return promise;
}


  /**
   * 群主主动拉人入群
   *
   * @param {Number} groupID 群ID
   * @param {Number[]} hhIDs 加群申请人ID数组
   * @param {function} successCallback 成功拉人入群后回调函数，定义为 .
   * 		successCallback(groupMember); groupMember 是 {Bmob.Object} 类，通过 groupMember.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "groupID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
function addGroupMembers(groupID, hhIDs, successCallback, errorCallback) {
	var promises = [];
	for (var i = 0; i < hhIDs.length; i++) {
		promises.push(addGroupMembersPromise(groupID, hhIDs[i]));
	}
	Bmob.Promise.when(promises).then(function() {
		successCallback();
	}, function(errors) {
		consoledebug.log('addGroupMembers some members save error is ' + JSON.stringify(errors));
		var error = {
			code : 888,
			massage : 'some members save error'
		}
		errorCallback(error);
	});

//	authorityCheck(groupID, function(group) {
//	}, errorCallback);
}

  /**
   * 删除组成员
   *
   * @param {Number} groupID 群ID
   * @param {Number[]} hhIDs 加群申请人ID数组
   * @param {function} successCallback 成功拉人入群后回调函数，定义为 .
   * 		successCallback(groupMember); groupMember 是 {Bmob.Object} 类，通过 groupMember.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "groupID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */

function systemRemoveGroupMembers(groupID, hhIDs, successCallback, errorCallback) {
	var GroupMembers = Bmob.Object.extend("GroupMembers");
	var query = new Bmob.Query(GroupMembers);
	query.equalTo("groupID", groupID);
	query.containedIn("hhID", hhIDs);
	query.destroyAll().then(successCallback, errorCallback);
}

  /**
   * 同意入群申请
   *
   * @param {Bmob.Object} member 是 GroupMembers 表的对象
   * @param {function} successCallback 成功拉人入群后回调函数，定义为 .
   * 		successCallback(groupMember); groupMember 是 {Bmob.Object} 类，通过 groupMember.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function agreeJoinGroup(member, successCallback, errorCallback){
      authorityCheck(member.get("groupID"), function (group) {
          member.set("state", 0);
          member.save().then(successCallback, errorCallback);
      },errorCallback);
  }

  /**
   * 群主主动删除一个成员
   *
   * @param {Number} groupID 群ID
   * @param {Number} hhID 移除人ID
   * @param {function} successCallback 成功拉人入群后回调函数，定义为 .
   * 		successCallback(groupMember); groupMember 是 {Bmob.Object} 类，通过 groupMember.get(key) 可获取值，
   * 		可用的 key 有 "hhID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function removeGroupMember(groupID, hhID, successCallback, errorCallback){
      authorityCheck(groupID, function (group) {
      	  consoledebug.log('authorityCheck group is ' + JSON.stringify(group));
          var GroupMembers = Bmob.Object.extend("GroupMembers");
          var query = new Bmob.Query(GroupMembers);
          query.equalTo("hhID", hhID);
          query.equalTo("groupID", groupID);
          query.find().then(function(members){
          	  consoledebug.log('removeGroupMember members is ' + JSON.stringify(members));
              if(members.length > 0){
                  members[0].destroy().then(successCallback, errorCallback);
              }else{
                  var err = new Object();
                  err.code = 200;
                  err.message = "No record";
                  errorCallback (err);
              }
          },errorCallback);
      },errorCallback);
  }

  /**
   * 退出群
   *
   * @param {Number} groupID 群ID
   * @param {function} successCallback 成功拉人入群后回调函数，定义为 .
   * 		successCallback();
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function quitGroup(groupID, successCallback, errorCallback){
      //确认是否是要退出自己创建的群，如果是，则删除整个群
      var myAcount = getMyAccount();
      authorityCheck(groupID, function (group) {
          removeGroup(groupID, successCallback, errorCallback);
      },function(error){
          var GroupMembers = Bmob.Object.extend("GroupMembers");
          var query = new Bmob.Query(GroupMembers);
          query.equalTo("hhID", myAcount.hhID);
          query.equalTo("groupID", groupID);
          query.find().then(function(members){
              if(members.length > 0){
                  members[0].destroy().then(function (member) {
                      successCallback();
                  }, errorCallback);
              }else{
                  var err = new Object();
                  err.code = 703;
                  err.message = "Not in the group";
                  errorCallback (err);
              }
          },errorCallback);
      });
  }

  function quitGroupByRyID(rongyunID, successCallback, errorCallback){
    getGroupInfoByRyid(rongyunID, function(gruopInfo){
        quitGroup(gruopInfo.get("groupID"), successCallback, errorCallback);
    }, errorCallback)
  }
  /**
   * 新建群号
   *
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(groupID); groupID 是 {Number}，
   * 		可用的 key 有 "groupID", "builderHHID", "groupName", "buildTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function newGroupID(successCallback, errorCallback) {
      var SerialNum = Bmob.Object.extend("serialNum");
      var query = new Bmob.Query(SerialNum);
      query.equalTo("serialName", "groupID");
      query.find({
          success: function(results) {
              if(results.length  == 0) {
                  var err = new Object();
                  err.code = 200;
                  err.message = "No record";
                  errorCallback (err);
                  return;
              }
              // 查询成功，调用get方法获取对应属性的值
              var serialNum = results [0];
              serialNum.fetchWhenSave(true);
              serialNum.increment("serialMatrix");
              serialNum.save().then(function(groupID) {
                  // The save was successful.
                  successCallback(groupID.get("serialMatrix"));
              }, function(error) {
                  // The save failed.  Error is an instance of Bmob.Error.
                  errorCallback (error);
              });
          },
          error: function(object, error) {
              // 查询失败
              errorCallback (error);
          }
      });
  }

  /**
   * 创建群
   *
   * @param {String} groupName 群名称
   * @param {String} rongyunID 融云IM 群ID
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(group); group 是 {Bmob.Object} 类，通过 group.get(key) 可获取值，
   * 		可用的 key 有 "groupID", "builderHHID", "rongyunID", "groupName", "buildTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function createGroup(groupName, rongyunID, successCallback, errorCallback, maintain){
      var myAcount = getMyAccount();
      if (myAcount) {
          newGroupID(function (groupID) {
              var Group = Bmob.Object.extend("Group");
              var group = new Group();
              group.set("builderHHID", myAcount.hhID);
              group.set("groupID", groupID);
              group.set("groupName", groupName);
              group.set("rongyunID", rongyunID);
              group.set("buildTime", new Date());
              if(maintain != undefined && maintain == 0){
                group.set("maintain", 0);
              }else{
                group.set("maintain", 1);
              }
              group.set("inSystemUse", 0);
              //添加数据，第一个入口参数是null
              group.save().then(function (group) {
                  var newGroup = group;
                  addGroupMember(group.get("groupID"),myAcount.hhID,function(member){
                      successCallback(newGroup);
                  },errorCallback);
              }, errorCallback);
          }, errorCallback);
      }
  }

  /**
   * 验证群操作权限
   *
   * @param {Number} groupID 删除好友的 ID
   * @param {function} rightsCallback 有权限的回调，定义为 .
   * 		rightsCallback(group); group 是 {Bmob.Object} 类，通过 group.get(key) 可获取值，
   * 		可用的 key 有 "groupID", "builderHHID", "groupName", "buildTime"
   * @param {function} noRightsCallback 操作失败后回调函数，定义为：
   * 		noRightsCallback(error); error is a class, {code: number, message:string}
   */
function authorityCheck(groupID, rightsCallback, noRightsCallback) {
    var err = new Object();
    var myAcount = getMyAccount();
    if (myAcount) {
        var Table = Bmob.Object.extend("Group");
        var query = new Bmob.Query(Table);
        query.equalTo("groupID", groupID);
        // 查询所有数据
        query.find().then(function(groups) {
        	consoledebug.log('authorityCheck groups is ' + JSON.stringify(groups));
            if (groups.length > 0) {
                if (groups[0].get('builderHHID') == myAcount.hhID && groups[0].get('inSystemUse') != 1) {
                    rightsCallback(groups[0]);
                } else {
                    err.code = 888;
                    err.message = "No right";
                    noRightsCallback(err);
                }
            } else {
                err.code = 888;
                err.message = "No record";
                noRightsCallback(err);
            }
        }, function(error) {
            err.code = 888;
            err.message = "No record";
            noRightsCallback(err);
        });
    }
}

  /**
   * 删除群
   *
   * @param {Number} groupID 删除好友的 ID
   * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
   * 		successCallback();
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
  function removeGroup(groupID, successCallback, errorCallback){
      authorityCheck(groupID, function (group) {
      	  consoledebug.log("removeGroup authorityCheck group is  " + JSON.stringify(group));
          group.destroy().then(function (deleteGroup) {
          	  consoledebug.log("removeGroup authorityCheck deleteGroup is  " + JSON.stringify(deleteGroup));
              var GroupMembers = Bmob.Object.extend("GroupMembers");
              var query = new Bmob.Query(GroupMembers);
              query.equalTo("groupID", deleteGroup.get("groupID"));
              query.find().then(function(members){
              	  consoledebug.log("removeGroup authorityCheck members is  " + JSON.stringify(members));
                  var promises = [];
                  for(var i=0;i<members.length;i++) {
                      promises.push(members[i].destroy());
                  }
                  return Bmob.Promise.when(promises);
              }).then(successCallback, errorCallback);
          }, errorCallback);
      },errorCallback);
  }
  
  
/**
   * 修改消息免打扰
   *
   * @param {Number} groupID
   * @param {String} newName 群新名称
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(group); group 是 {Bmob.Object} 类，通过 group.get(key) 可获取值，
   * 		可用的 key 有 "groupID", "builderHHID", "rongyunID", "groupName", "buildTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
//function modefyGroupName(groupID, noDisturb, successCallback, errorCallback){
//    authorityCheck(groupID, function (group) {
//        group.set('noDisturb', noDisturb);
//        group.save().then(function (group) {
//            successCallback(group);
//        }, errorCallback);
//    },errorCallback);
//}
  
  
  /**
   * 修改群名称
   *
   * @param {Number} groupID
   * @param {String} newName 群新名称
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(group); group 是 {Bmob.Object} 类，通过 group.get(key) 可获取值，
   * 		可用的 key 有 "groupID", "builderHHID", "rongyunID", "groupName", "buildTime"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */
//function modefyGroupName(groupID, newName, successCallback, errorCallback){
//    authorityCheck(groupID, function (group) {
//        group.set('groupName', newName);
//        group.save().then(function (group) {
//            successCallback(group);
//        }, errorCallback);
//    },errorCallback);
//}
//
////修改上传群头像
// function modefyGroupPhoto(groupID, newPhoto, successCallback, errorCallback){
//    authorityCheck(groupID, function (group) {
//        group.set('photo', newPhoto);
//        group.save().then(function (group) {
//            successCallback(group);
//        }, errorCallback);
//    },errorCallback);
//}
  
	function modefyGroupInfo(groupID, newName, newPhoto, maintain, successCallback, errorCallback) {
		if(newName || newPhoto || maintain){
			getGroupInfo(groupID, function(group) {
				if(newName){
					group.set('groupName', newName);
				}
				if(newPhoto){
					group.set('photo', newPhoto);
				}
				if(maintain){
					group.set('maintain', maintain);
				}
				group.save().then(function(group) {
					successCallback(group);
				}, errorCallback);
			}, errorCallback);
		}else{
			consoledebug.log('modefyGroupInfo newName newPhoto is ' + newName + newPhoto);
			successCallback();
		}
	}

  /**
   * 修改我在某群中的昵称
   *
   * @param {Number} groupID: 群ID
   * @param {String} newName: 自己在群里的新昵称
   * @param {function} successCallback 成功获取群列表后回调函数，定义为 .
   * 		successCallback(members); members 是 {Bmob.Object} 类数组，通过 members[x].get(key) 可获取值，
   * 		可用的 key 有 "hhID", "groupID", "state", "reason", "nickname"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errCallback(error); error is a class, {code: number, message:string}
   */

function modefyMyGroupMemberName(groupID, newName, noDisturb, successCallback, errorCallback) {
	if (newName || noDisturb !== undefined) {
		var myAcount = getMyAccount();
		if (myAcount) {
			var Table = Bmob.Object.extend("GroupMembers");
			var query = new Bmob.Query(Table);
			query.equalTo("groupID", groupID);
			query.equalTo("hhID", myAcount.hhID);
			// 查询所有数据
			query.find({
				success : function(member) {
					if (member.length > 0 && member[0].get("groupID") == groupID) {
						if(newName){
							member[0].set('nickname', newName);
						}
						if(noDisturb !== undefined){
							member[0].set('noDisturb', noDisturb);
						}
						member[0].save().then(function(member) {
							successCallback(member);
						}, errorCallback);
					} else {
						err.code = 707;
						err.message = "No member";
						errorCallback(err);
					}
				},
				error : function(error) {
					errorCallback(error);
				}
			});
		}
	}else{
		successCallback();
	}
}
