var gMyUserInfo;

  /**
   * 根据用户昵称查找 hhID
   *
   * @param {String} nickname 用户昵称
   * @param {function} successCallback 查找所有跟用户昵称匹配的用户列表，定义为 .
   *        successCallback(UserInfo); UserInfo 是 {Bmob.Object} 类对象数组，通过 UserInfo[x].get(key) 可获取值，
   *        可用的 key 有 "hhID", "nickName", "sex", "level", "age", "photo", "location", "onlineTime", "appraisement"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   *        errCallback(error); error is a class, {code: number, message:string}
   */
function getUserInfo(hhID, successCallback, errorCallback){
	var UserInfo = Bmob.Object.extend("UserInfo");
	var query = new Bmob.Query(UserInfo);
	query.equalTo("hhID", hhID); 
	// 查询所有数据
	query.find({
	    success: function(results) {
	        // 循环处理查询到的数据
	        if(results.length > 0) {
		        var userInfo = results[0];
		        successCallback(userInfo);
//		        var objUserInfo = {};
//				keys = ["hhID", "nickName","describe","photo","photoThumbnail","sex","age","level","livingPlace","appraisement","partnerNum","partnerTime","validateState"];
//				bmob2Obj(keys, userInfo, objUserInfo);
//				if(objUserInfo.photoThumbnail && objUserInfo.photoThumbnail != ''){
//					convertImgToBase64(objUserInfo.photoThumbnail, function(urlData){
//						objUserInfo.photo = urlData;
//						inertCacheUserInfo(objUserInfo, function(){},function(error){});
//					})
//				}
	        }else{
	        	//api.toast({msg: "无法查到记录", location: 'middle'});
	        }
	    },
	    error: function(error) {
	        errorCallback(error);
	    }
	});
}

  /**
   * 获取用户信息集合
   *
   * @param {Number[]} hhIDs: 存储要查询的用户信息的 hhID 数组
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(userInfos); userInfos 是 {Object[]} 对象数组，
   * 		单个数组元素的定义见 getUserInfo 方法
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(error); error is a class, {code: number, message:string}
   */

function getNetUserInfos(hhIDs, successCallback, errorCallback) {
	var err = {};
    if (hhIDs.length < 1) {
        err.code = 888;
        err.message = "length cannot be 0";
        errorCallback(err);
        return;
    }
    if(typeof hhIDs[0] != 'number'){
        consoledebug.log('error getNetUserInfos hhIDs is not number' + typeof hhIDs[0]);
        err.code = 888;
        err.message = "hhIDs type is not number";
        errorCallback(err);
        return;
    }
    var UserInfo = Bmob.Object.extend("UserInfo");
    var query = new Bmob.Query(UserInfo);
    query.containedIn("hhID", hhIDs);
    // 查询所有数据
    query.find({
        success : function(results) {
            // 循环处理查询到的数据
            if (results.length > 0) {
                successCallback(results);
            } else {
                var err = {};
                err.code = 888;
                err.message = "length is 0";
                errorCallback(err);
            }
        },
        error : function(error) {
            errorCallback(error);
        }
    });
}

//successCallback : successCallback(var user); var user is the Bmob.user
//errorCallback : errCallback(var error); var error is a class, {code: number, message:string}
function getMyInfo(successCallback, errorCallback){
    //防止退出登录后的数据缓存
    var myAcount = getMyAccount();
	if(gMyUserInfo && (gMyUserInfo.get('hhID') == myAcount.hhID)){
		successCallback(gMyUserInfo);
	}else{
		//var currentUser = getCurrentUser();
		if (myAcount) {
			getUserInfo(myAcount.hhID, function(myInfo){
				gMyUserInfo = myInfo;
				successCallback(gMyUserInfo);
			}, errorCallback);
		}
	}
}


//successCallback : successCallback(var PhotoWall); var PhotoWall is the Photo files array
//{url:string, filename:string}
//errorCallback : errCallback(var error); var error is a class, {code: number, message:string}
var gPhotoWall = [];
var baseUrl = "http://file.bmob.cn/";
function getPhotoWall(hhID, weight, height, successCallback, errorCallback) {
    var PhotoWall = Bmob.Object.extend("PhotoWall");
    var query = new Bmob.Query(PhotoWall);
    query.equalTo("hhID", hhID);
    //query.select("photo");
    query.ascending("updatedAt");
    // 查询所有数据
    query.find().then(function(results) {
    	gPhotoWall = results;
    	successCallback(results);
    },function(error){
    	consoledebug.log('getPhotoWall error is '+ JSON.stringify(error));
    	errorCallback(error);
    });
}

function makePhotoWallThumbnail(inFile, outFile){
    var oUrl = inFile.url();
    if(!weight || !height){
    	weight = 82;
    	height = 82;
    }
    var promise = new Bmob.Promise();
    Bmob.Image.thumbnail({
        "image" : oUrl,
        "mode" : 3,
        "quality" : 100,
        "shortEdge" : 84,
        "outType" : 0
    }).then(function(obj) {
        consoledebug.log('photo thumbnail 1 is ' + JSON.stringify(obj));
	    Bmob.Image.thumbnail({
	        "image" : baseUrl + obj.url,
	        "mode" : 5,
	        "quality" : 100,
	        "width" : 84,
	        "height" : 84
	    }).then(function(obj) {
	        outFile.url = baseUrl + obj.url;
	        outFile.orgId = inFile.id;
	        consoledebug.log('photo thumbnail 2 is ' + outFile.url + outFile.orgId);
	        promise.resolve(outFile);
	    },function(error){
	        promise.reject(error);
	        consoledebug.log('photo thumbnail 2 failed ' + JSON.stringify(error));
	    });
    },function(error){
        promise.reject(error);
        consoledebug.log('photo thumbnail 1 failed ' + JSON.stringify(error));
    });

    return promise;
}

function makeThumbnail(weight, height, inFile, outFile){
    var oUrl = inFile.url();
    consoledebug.log('makeThumbnail w:' + weight + ', h:' + height + oUrl);
    if(!weight || !height){
    	weight = 82;
    	height = 82;
    }
    var shortEdge = weight > height ? weight : height
    var promise = new Bmob.Promise();
    var thumPromis = Bmob.Image.thumbnail({
        "image" : oUrl,
        "mode" : 3,
        "quality" : 100,
        "shortEdge" : shortEdge
    }).then(function(obj) {
        outFile.url = baseUrl + obj.url;
        outFile.orgId = inFile.id;
        consoledebug.log('photo thumbnail is ' + outFile.url + outFile.orgId);
        promise.resolve(outFile);
        //successCallback(outFile);
//				alert("filename:" + obj.filename);
//				alert("url:" + obj.url);
    },function(error){
        promise.reject(error);
        consoledebug.log('photo thumbnail failed ' + JSON.stringify(error));
    });

    return promise;
}

//function getAvatarThumbnail(url, outObj){
//  consoledebug.log('getAvatarThumbnail ' + url);
//  var promise = new Bmob.Promise();
//  var thumPromis = Bmob.Image.thumbnail({
//      "image" : url,
//      "mode" : 5,
//      "quality" : 100,
//      "width" : 64,
//      "height" : 64,
//      "outType" : 1
//  }).then(function(obj) {
//      outObj.photo = 'data:image/png;base64,' + obj.file;
//      consoledebug.log('getAvatarThumbnail is ' + outObj.photo);
//      promise.resolve();
//  },function(error){
//      promise.reject(error);
//      consoledebug.log('getAvatarThumbnail failed ' + error.message);
//  });
//
//  return promise;
//}

function getAvatarThumbnail(url, outObj){
	consoledebug.log('getAvatarThumbnail ' + url);
    var promise = new Bmob.Promise();
	convertImgToBase64(url, function(photourl) {
		outObj.photo = photourl;
        consoledebug.log('getAvatarThumbnail is ' + outObj.photo);
        promise.resolve();
	});
	return promise;					
}
function convertImgToBase64(url, callback, dWidth, dHeight) {
	var canvas = document.createElement('CANVAS'), ctx = canvas.getContext('2d'), img = new Image;
	img.crossOrigin = 'Anonymous';
	img.onload = function() {
		var dataURL;
		var scale = 1;
		if(dHeight && dWidth){
        	if(img.width/img.height > dWidth/dHeight){
        		scale = dHeight/img.height
        	}else{
        		scale = dWidth/img.width
        	}
			scale = (scale > 1) ? 1 : scale;
		}
        consoledebug.log("convertImgToBase64 scale is " + scale + " img height is "+img.height + " width " + img.width);
		canvas.height = img.height;
		canvas.width = img.width;
		ctx.drawImage(img, 0, 0);
		dataURL = canvas.toDataURL("image/png", scale);
		callback.call(this, dataURL);
		canvas = null;
	};
	img.src = url;
}

  /**
   * 获取用户集合的头像
   *
   * @param {Object[]} avatarObjs: 要查询的用户集合信息，
   * 		包含的 属性有： {Number} hhID, {String} url
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(avatarArray); userInfos 是 {Object[]} 对象数组，
   * 		包含的 属性有： {Number} hhID, {String} photo
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(); }
   */
function getAvatarArray(avatarObjs, successCallback, errorCallback) {
	var avatarArray = new Array(avatarObjs.length);
	//var i = 0;
	var promises = [];
//	$.each(avatarObjs, function() {
//		var avatarObj = this;
//		avatarArray[i] = new Object();
//		avatarArray[i].hhID = avatarObj.hhID;
//		var thuPromise = getAvatarThumbnail(avatarObj.url, avatarArray[i]);
//		i++;
//		promises.push(thuPromise);
//	});
    for(var i=0;i<avatarObjs.length;i++){
		avatarArray[i] = {};
		avatarArray[i].hhID = avatarObjs[i].hhID;
        promises.push(getAvatarThumbnail(avatarObjs[i].url, avatarArray[i]));
    }
	Bmob.Promise.when(promises).then(function(){
//	var alldone = Bmob.Promise.when(promises);
//	alldone.then(function (){
		successCallback(avatarArray);
	}, function(){
		errorCallback();
	});
}

function deleteFile(url) {
    //var fileUrl = url.substring(baseUrl.length, url.length);
    var fileUrl=url.replace(baseUrl,"");
    var apiUrl = '/files/' + fileUrl;
	consoledebug.log('deleteFile url is '+apiUrl);
    BmobajaxRequest(apiUrl, 'delete', null, function (ret, err) {
        if (ret) {
			consoledebug.log('deleteFile success '+ret);
        } else {
        	consoledebug.log('deleteFile error '+err.msg);
        }
    })
}

function removeFromPhotoWall(url){
	var i = 0;
	for(i = 0; i<gPhotoWall.length; i++){
		if(gPhotoWall[i].get('photoThumbnail') == url){
		    var file = gPhotoWall[i].get('photo');
			consoledebug.log('removeFromPhotoWall is ' + file._url + gPhotoWall[i].get('photoThumbnail'));
		    deleteFile(file._url);
		    deleteFile(gPhotoWall[i].get('photoThumbnail'))
			gPhotoWall[i].destroy();
			gPhotoWall.remove(i); 
			break;
		}
	}
}

//function getPhotoWall(hhID, weight, height, successCallback, errorCallback) {
//	var PhotoWall = Bmob.Object.extend("PhotoWall");
//	var query = new Bmob.Query(PhotoWall);
//	query.equalTo("hhID", hhID);
//	query.select("photo");
//  query.ascending("updatedAt");
//	// 查询所有数据
//	query.find().then(function(results) {
//		// Collect one promise for each delete into an array.
//		consoledebug.log('getPhotoWall number is '+results.length);
//		var promises = [];
//		photoWall = results;
//		for(var i = 0; i<results.length; i++) {
//			var result = results[i];
//			var file = result.get('photo');
//			var oUrl = file._url;
//			var tUrl;
//			var thumPromis = Bmob.Image.thumbnail({
//				"image" : oUrl,
//				"mode" : 5,
//				"quality" : 100,
//				"width" : weight,
//				"height" : height
//			}).then(function(obj) {
//				obj.url = baseUrl + obj.url;
//				obj.orgId = result.id;
//				consoledebug.log(i + 'photo thumbnail is ' + obj.url + obj.orgId);
//				successCallback(obj);
//
////				alert("filename:" + obj.filename);
////				alert("url:" + obj.url);
//			},function(error){
//				consoledebug.log(i + 'photo thumbnail failed ' + error.message);
//			});
//			promises.push(thumPromis);
//
//		};
//		// Return a new promise that is resolved when all of the deletes are finished.
//		return Bmob.Promise.when(promises);
//
//	}).then(function() {
//		// Every comment was deleted.
//		//successCallback(results);
//	});
//}

//successCallback : successCallback(var PhotoWall); var PhotoWall is the PhotoWall array
//errorCallback : errCallback(var error); var error is a class, {code: number, message:string}
function getMyPhoto(w, h, successCallback, errorCallback) {
	consoledebug.log('getMyPhoto w:'+ w +', h:'+ h);
    var myAcount = getMyAccount();
	if (myAcount) {
		getPhotoWall(myAcount.hhID, w, h, successCallback, errorCallback);
	}
}

function savePhoto(fileName, bytes) {
	var file = BmobFile(fileName, bytes);
	file.save().then(function(obj) {
	  consoledebug.log('savePhoto1 is '+ obj.url());
	}, function(error) {
	  // the save failed.
	  consoledebug.log('savePhoto1 error '+error.message);
	});
}

  /**
   * 将图片文件和照片墙表中的 photo 字段关联起来
   * 注意！！！！
   * Bmob.File 和 数据库 File 类型数据是不一样的。可能是JS SDK 设计不仔细，
   * Bmob.File 类型中，存储文件名的 key 叫 name， 而数据库数据类型 File 里存储文件名的 key 叫 filename
   * //// 上面的问题在 1.1.1 版 SDK 中已经修复，现在可以直接用 file 对象了。
   *
   * @param {Number} hhID: 照片墙主人的 hhID
   * @param {Bmob.File} obj: 存储文件返回的对象
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(photowall); photowall 是 {Bmob.Object} 对象，PhotoWall 表的一行
   * 		photowall.get(key) 可获取值，可用的 key 有"hhID",  "photo"
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(error); error is a class, {code: number, message:string}
   */
function relationFile(hhID, obj, successCallback, errorCallback) {
    var apiUrl = '/classes/PhotoWall';
    var fullUrl = obj.url();
	consoledebug.log('fullUrl is '+fullUrl);
    var fileUrl = fullUrl.substring(baseUrl.length, fullUrl.length);
	consoledebug.log('fileUrl is '+fileUrl);
    var bodyParam = {
        hhID: hhID,
        photo: {
	        __type: "File",
	        group: obj.group(),
	        filename: obj.name(),
	        url: fileUrl
    	}
    }
    consoledebug.log('relationFile body is '+ JSON.stringify(bodyParam));
    BmobajaxRequest(apiUrl, 'post', JSON.stringify(bodyParam), function (ret, err) {
        if (ret) {
			var PhotoWall = Bmob.Object.extend("PhotoWall");
			var photoWall = new PhotoWall();
			photoWall.id = ret.objectId;
			photoWall.createdAt = ret.createdAt;
			photoWall.updatedAt = ret.createdAt;
			photoWall.set("hhID",hhID);
			var photoFile = {};
			photoFile._url = fullUrl;
			photoWall.set("photo",photoFile);
			consoledebug.log('relationFile success '+JSON.stringify(ret));
			successCallback(photoWall);
        } else {
        	consoledebug.log('relationFile error '+err.msg);
			errorCallback(error);
        }
    })
}


function savePhotoWall(imagePath, successCallback, errorCallback){
    var hhID = getMyAccount().hhID;
    //var imageExt = "." + getFileExt(imagePath);
    var imageExt = ".png";
    imgThumbnailCompress(imagePath, 128, 128, function(ThumbnailPath){
        photoClip(ThumbnailPath, 128, 128, function(dataurl){
            var Tphoto;
            var data = dataurl.split(',')[1];
            data = window.atob(data);
            var fileName = hhID + new Date().Format("-yy-MM-dd-hh:mm:ss.S") + imageExt;
            var file = BmobFile(fileName, data);
            file.save().then(function (obj) {
                Tphoto = obj;
                
                imgThumbnailCompress(imagePath, 500, 500, function(orgPath){                    
                    convertImgToBase64(orgPath, function(orgDataurl){
                        var data = orgDataurl.split(',')[1];
                        data = window.atob(data);
                        var fileName = hhID + new Date().Format("-yy-MM-dd-hh:mm:ss.S") + imageExt;
                        var tfile = BmobFile(fileName, data);
                        tfile.save().then(function (obj) {
                            successCallback(obj, Tphoto);
                        }, function(error){
                            file.destroy();
                            errorCallback(error);
                        })
                    });
                })
    
            }, function (error) {
                // the save failed.
                errorCallback(error);
            });
        })
    })
}

function savePhotoWallInfo(userInfoRecord, oPhotoFile, tPhotoFile, successCallback, errorCallback) {
    var PhotoWall = Bmob.Object.extend("PhotoWall");
    var myPhotoWall = new PhotoWall();
    myPhotoWall.set('hhID', userInfoRecord.get("hhID"));
    myPhotoWall.set('photo', oPhotoFile);
    myPhotoWall.set('photoThumbnail', tPhotoFile.url());
    myPhotoWall.set('owner', userInfoRecord);
    myPhotoWall.save().then(function(obj) {
        consoledebug.log('save PhotoWall success ');
        var relation = userInfoRecord.relation("photoWall");
        relation.add(myPhotoWall);
        userInfoRecord.save();
        gPhotoWall.push(obj);
        successCallback(obj);
    }, function(error) {
        consoledebug.log('save PhotoWall error ' + JSON.stringify(error));
        errorCallback(error);
    });
}

  /**
   * 获取头像图标
   *
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(avatarUrl); photo 是 {String} 对象，是返回的头像url
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(error); error is a class, {code: number, message:string}
   */
function getHDAvatar(successCallback, errorCallback){
	var avatarUrl;
    var myAcount = getMyAccount();
	if (myAcount) {
	    var Table = Bmob.Object.extend("UserInfo");
	    var query = new Bmob.Query(Table);
	    query.equalTo("hhID", myAcount.hhID);
	    query.select("photo");
	    query.find().then(function(results) {
	    	if(results.length > 0){
	        	var fileUrl = results[0].get('photo');
	        	if(fileUrl){
	        		avatarUrl = fileUrl;
	        	}
	    	}
	    	successCallback(avatarUrl);
	    },function (error){
			errorCallback(error);
	    });
	}
}

  /**
   * 更新头像图标
   *
   * @param {String} dataurl: 照片的 base64 编码
   * @param {function} successCallback 成功后回调函数，定义为 .
   * 		successCallback(avatarUrl); photo 是 {String} 对象，是返回的头像url
   * @param {function} errorCallback 操作失败后回调函数，定义为：
   * 		errorCallback(error); error is a class, {code: number, message:string}
   */
function updateAvatar(userInfoRecord, dataurl, successCallback, errorCallback){
    var myAcount = getMyAccount();
	//var currentUser = getCurrentUser();
	if (myAcount) {
		var hhID = myAcount.hhID;
		var data = dataurl.split(',')[1];
		data = window.atob(data);
		var fileName = hhID + new Date().Format("yyyy-MM-dd-hh:mm:ss") + '.png';
		consoledebug.log('fileName is '+ fileName);
		var file = BmobFile(fileName, data);
		file.save().then(function(obj) {
			consoledebug.log('savePhoto success '+ obj.url() + obj.name());
            var tFile = {};
            makeThumbnail(80, 80, obj, tFile).then(function(tPhoto) {
                var fileUrl = userInfoRecord.get('photo');
                var fileThumbnailUrl = userInfoRecord.get('photoThumbnail');
                if (fileUrl) {
                    deleteFile(fileUrl);
                }
                if (fileThumbnailUrl) {
                    deleteFile(fileThumbnailUrl);
                }
                userInfoRecord.set('photo', obj.url());
                userInfoRecord.set('photoThumbnail', tFile.url);
                var myDate = new Date();
                var updateUserInfoTime = myDate.getTime();
                userInfoRecord.set('updateUserInfoTime', updateUserInfoTime);
                userInfoRecord.save().then(function(myInfo) {
                    consoledebug.log('userInfoRecord save success '+ obj.url() + tFile.url);
                    successCallback(myInfo.get('photo'));
                }, function(error) {
                    deleteFile(obj.url());
                    deleteFile(tFile.url);
                    errorCallback(error);
                    consoledebug.log('userInfoRecord save error ' + JSON.stringify(error));
                }); 
            },function(error){
                consoledebug.log('makeThumbnail userInfo error ' + JSON.stringify(error));
                deleteFile(obj.url());
		    	errorCallback(error);
            });    
		}, function(error) {
		  // the save failed.
		    errorCallback(error);
			consoledebug.log('updateAvatar file save error '+JSON.stringify(error));
		});
	}
}


/**
 * 上传更新自己的位置
 *
 * @param {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function updateLocation(successCallback, errorCallback){
	var bMap = api.require('bMap');
	bMap.getLocation({
		accuracy: '100m',
		autoStop: true,
		filter: 1
	}, function(ret, err){
		if(ret.status){
			consoledebug.log('getLocation is ' + JSON.stringify(ret));
			var point = new Bmob.GeoPoint({latitude: ret.lat, longitude: ret.lon});
			var UserInfo = Bmob.Object.extend("UserInfo");
            var myInfo = new UserInfo();
            var myAccount = getMyAccount();
            if(myAccount.userInfoId){
                myInfo.id = myAccount.userInfoId;
                myInfo.set('location', point);
                myInfo.save().then(function(myInfo) {
                    successCallback(point);
                }, function(error) {
                    errorCallback(error);
                    consoledebug.log('updateLocation save userInfo error ' + error.message);
                }); 
            }else{
                var err = {
                    code: 888,
                    message: "myAccount userInfoId leak"
                }
                errorCallback(err);
            }
		}else{
			consoledebug.log('getLocation error code is ' + err.code);
			err.message = err.msg;
			errorCallback(err);
		}
	});
}

function makeUserInfoObj(myLocation, userInfos){
	var list = [];
	for(var i=0; i<userInfos.length; i++){
		var info = {};
		if (userInfos[i].get("hhID") != undefined) {
			info.hhID = userInfos[i].get("hhID");       //用户ID号
		}
		if (userInfos[i].get("nickName") != undefined) {
			info.nickName = userInfos[i].get("nickName");   //用户昵称
		}
		if (userInfos[i].get("sex") != undefined) {
			info.sex = userInfos[i].get("sex");        //性别
		}
//		if (userInfos[i].get("birthday") != undefined) {
//			info.birthday = userInfos[i].get("birthday");      //生日
//		}
		if (userInfos[i].get("age") != undefined) {
			info.age = userInfos[i].get("age");      //年龄
		}
		if (userInfos[i].get("level") != undefined) {
			info.level = userInfos[i].get("level");      //等级
		}
		if (userInfos[i].get("describe") != undefined) {
			info.describe = userInfos[i].get("describe");   //自我介绍
		}
		if (userInfos[i].get("appraisement") != undefined) {
			info.appraisement = userInfos[i].get("appraisement");   //心形评价
		}
		if (userInfos[i].get("livingPlace") != undefined) {
			info.livingPlace = userInfos[i].get("livingPlace"); //居住地
		}
		if (userInfos[i].get("photoThumbnail") != undefined) {
			info.dataurl = userInfos[i].get("photoThumbnail");   //照片，为 dataUrl 格式的字符串
		}else if(userInfos[i].get("photo") != undefined){
            info.dataurl = userInfos[i].get("photo");   //照片，为 dataUrl 格式的字符串
		}
		if (userInfos[i].get("onlineTime") != undefined) {
			info.onlineTime = userInfos[i].get("onlineTime"); //最近在线时间
		}
		if (userInfos[i].get("industry") != undefined) {
			info.industry = userInfos[i].get("industry");
		}
		//info.updateAt = userInfos[i].get("updateAt");   //记录最新更新时间
		var date = new Date();
		var date2 = new Date(userInfos[i].updatedAt.replace(new RegExp("-","gm"),"/"));
		var d = date.getTime() - date2.getTime();
		var min = d /(60000);
		if(min >= 1440){
	      var d = min /60/24;
	      info.updateAt = Math.floor(d) + '天';
    	}else if(min > 59){
			var h = min / 60;
			info.updateAt = Math.floor(h) + '小时';
		}else if(min>1||min<59){
			info.updateAt = Math.ceil(min) + '分钟';
		}else{
			info.updateAt = '30分钟';
		}
		if (userInfos[i].get("location") != undefined) {
            var miles = myLocation.kilometersTo(userInfos[i].get("location")) * 1000;
            if (miles > 10000){
                miles = miles / 1000;
                info.location = Math.ceil(miles) + "km"; //距离位置信息
            }else if (miles > 1000) {
                miles = miles / 1000;
                info.location = miles.toFixed(1) + "km"; //距离位置信息
            } else if(miles >100){
                info.location = Math.ceil(miles) + "m"; //距离位置信息
            } else{
            	info.location = '100m';
            }
		}
		list.push(info);
	}
	return list;
}
/**
 * 获取附近人列表，查询条件是4小时内在线的用户中，按照地理位置排序
 *
 * @param {Bmob.GeoPoint} userGeoPoint: 自己的地理位置
 * @param {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(userInfos);
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
var gNearbyUserQuery;
function getNearbyUser(userGeoPoint, successCallback, errorCallback){
    var myAcount = getMyAccount();
    //var currentUser = getCurrentUser();
    if (!myAcount) {
        consoledebug.log('getNearbyUser myAcount failed. ');
        return;
    }
    var ShieldQuery = Bmob.Object.extend("ShieldQuery");
    var shieldQuery = new Bmob.Query(ShieldQuery);
    shieldQuery.equalTo("ownerID", getMyAccount().hhID);
    
	var UserInfo = Bmob.Object.extend("UserInfo");
	gNearbyUserQuery = new Bmob.Query(UserInfo);
	gSkipNum = 0;
	gNearbyUserQuery.near("location", userGeoPoint);
	var date = new Date();
	var date2 = date.getTime() - 24*60*60*1000*7;	//24小时之前的时间
	date.setTime(date2);
    consoledebug.log('getNearbyUser date is ' + date.toString());
    
    gNearbyUserQuery.doesNotMatchKeyInQuery("hhID", "targetID", shieldQuery);
    
	gNearbyUserQuery.greaterThan("updatedAt", date);
	gNearbyUserQuery.limit(20);
	gNearbyUserQuery.notContainedIn("hhID", [myAcount.hhID]);
	gNearbyUserQuery.find().then(function(userInfos){
		var userList = makeUserInfoObj(userGeoPoint, userInfos);
		successCallback(userList);
	},errorCallback);
}



/**
 * 获取附近人列表下一页
 *
 * @param {Bmob.GeoPoint} userGeoPoint: 自己的地理位置
 * @param {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
var gSkipNum = 0;
function getNearbyUserNextPage(userGeoPoint, successCallback, errorCallback){
	if(gNearbyUserQuery){
		gSkipNum += 20;
		gNearbyUserQuery.skip(gSkipNum);
		gNearbyUserQuery.limit(20);
        gNearbyUserQuery.find().then(function(userInfos){
            var userList = makeUserInfoObj(userGeoPoint, userInfos);
            successCallback(userList);
        },errorCallback);
	}else{
		getNearbyUser(userGeoPoint, successCallback, errorCallback);
	}
}

/**
 * 个人详情页面，点击举报，在工单号列表中，添加被举报人相应信息。

 */
function NewHelpTables(htinteractionInfo,successCallback,errorCallback){
    var DetailsReport = Bmob.Object.extend("Details_Report");
    var Htinteraction = new DetailsReport();
    Htinteraction.set("targetID",htinteractionInfo.get("hhID"));
    // Htinteraction.set("orderID",htinteractionInfo.get("hhID"));
    // Htinteraction.set("orderName",htinteractionInfo.get("orderName"));
    Htinteraction.set("YN_type",0);
    Htinteraction.set("validate_sign",6);
    Htinteraction.set("order_type",3);
    Htinteraction.save().then(function(NHtinteraction){
        successCallback(NHtinteraction);
    },function(error){
        errorCallback(error);
    })
}

//拉黑功能
function insertShieldPeople(ownerID,targetID,successCallback,errorCallback){
	var ShieldQuery = Bmob.Object.extend("ShieldQuery");
    var ShieldQuery = new ShieldQuery();
    ShieldQuery.set("ownerID",ownerID);
    ShieldQuery.set("targetID",targetID);
    ShieldQuery.save().then(function(ShieldInfo){
        successCallback(ShieldInfo);
    },function(error){
        errorCallback(error);
    })
}

