/**
 * 发布公告
 * @param {Object} announcement:  类对象，公告信息
 * 包含的属性 为：{
   *            groupID: String.        //组ID
 *              title: String,        //标题
 *              content: String,        //内容
  *             }
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function issueAnnouncement(announcement, successCallback, errorCallback){
    var myAccount = getMyAccount();
    if (myAccount) {
        var Table = Bmob.Object.extend("GroupAnnouncement");
        var record = new Table();
        record.set("groupID", announcement.groupID);
        record.set("title", announcement.title);
        record.set("content", announcement.content);
        record.set("ownerID", myAccount.hhID);
        record.save().then(function(record) {
            successCallback(record);
        }, function(error) {
            consoledebug.log('issueAnnouncement save error is '+ JSON.stringify(error));
            errorCallback(error);
        });
    }
}


/**
 * 获取公告
 * @param groupID 群ID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(announcements); announcements 是 {Bmob.Object []} 类数组，通过 announcements[x].get(key) 可获取值，
 * 		可用的 key 有 groupID,title,content,ownerID,
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function GetGroupAnnouncement(groupID, successCallback, errorCallback) {
    var Table = Bmob.Object.extend("GroupAnnouncement");
    var query = new Bmob.Query(Table);
    query.equalTo("groupID",groupID);
    query.descending("createdAt");
    query.find().then(function(announcements) {
        successCallback(announcements);
    },function(error) {
        consoledebug.log('GetGroupAnnouncement find error is '+ JSON.stringify(error));
        errorCallback(error);
    });
}

/**
 * 获取某一条公告
 * @param groupID 群ID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(announcements); announcements 是 {Bmob.Object []} 类数组，通过 announcements[x].get(key) 可获取值，
 * 		可用的 key 有 groupID,title,content,ownerID,
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function GetGroupOneAnnouncement(ID, successCallback, errorCallback) {
	consoledebug.log('GetGroupOneAnnouncement ID is '+ ID);
    var Table = Bmob.Object.extend("GroupAnnouncement");
    var query = new Bmob.Query(Table);
   	query.get(ID,function(results){
   		successCallback(results)
   	},function(error){
   		errorCallback(error);
   	})
}



/**
 * 删除公告
 * @param announcementID 公告bmob 类中的 id 值
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function deleteGroupAnnouncement(announcementID, successCallback, errorCallback) {
    var Table = Bmob.Object.extend("GroupAnnouncement");
    var query = new Bmob.Query(Table);
    query.equalTo("objectId", announcementID);
    query.destroyAll({
        success : function() {
            successCallback();
        },
        error : function(error) {
            consoledebug.log('deleteGroupAnnouncement destroyAll error is '+ JSON.stringify(error));
            errorCallback(error);
        }
    });
}

/**
 * 发布投票
 * @param {Object} vote:  类对象，公告信息
 * 包含的属性 为：{
   *            groupID: String.        //组ID
 *              title: String,        //标题
 *              options: String[],        //选项内容数组
 *              mode: Number,       //投票模式，0为单选，1为多选
  *             }
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function issueVote(vote, successCallback, errorCallback){
    var myAccount = getMyAccount();
    if (myAccount) {
        var Table = Bmob.Object.extend("GroupVote");
        var record = new Table();
        record.set("groupID", vote.groupID);
        record.set("title", vote.title);
        record.set("options", vote.options);
        record.set("ownerID", myAccount.hhID);
        record.set("state", 1);     //0为已结束投票，1为正在投票中
        record.set("mode", vote.mode);     //投票模式，0为单选，1为多选
        record.save().then(function(record) {
            successCallback(record);
        }, function(error) {
            consoledebug.log('issueVote save error is '+ JSON.stringify(error));
            errorCallback(error);
        });
    }
}

/**
 * 投票
 * @param {Bmob.Object} voteRecord:  类对象，公告信息
 * @param {Number[]} selections  选择的选项，为 options 字段的index 数组
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function makeVote(voteRecord, selections, successCallback, errorCallback){
    var myAccount = getMyAccount();
    if (myAccount) {
    
        var Table = Bmob.Object.extend("MakeVoteState");
        var voteState = new Table();
        voteState.set("groupID", voteRecord.get("groupID"));
        voteState.set("Id", voteRecord.id);
        voteState.set("hhID", myAccount.hhID);
        voteState.save().then(function() {
//          successCallback(voteState);
			for(var i=0;i<selections.length;i++){
	            voteRecord.addUnique('option' + selections[i], myAccount.hhID);
	        }
	        consoledebug.log("makeVote voteRecord is  " + JSON.stringify(voteRecord));
	        voteRecord.save().then(function(record) {
	        	consoledebug.log("makeVote record is  " + JSON.stringify(record));
	            successCallback(record);
	        }, function(error) {
	            consoledebug.log('makeVote save error is '+ JSON.stringify(error));
	            errorCallback(error);
	        });

        }, function(error) {
            consoledebug.log('makeVote save error is '+ JSON.stringify(error));
            errorCallback(error);
        });
        
        
    }
}


/**
 * 获取投票状态
 * @param groupID 群ID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(votes); votes 是 {Bmob.Object []} 类数组，通过 votes[x].get(key) 可获取值，
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function GetGroupVoteState(groupID,hhID, successCallback, errorCallback) {
    var Table = Bmob.Object.extend("MakeVoteState");
    var query = new Bmob.Query(Table);
    query.equalTo("groupID",groupID);
    query.equalTo("hhID",hhID);
    query.descending("createdAt");
    query.find().then(function(voteState) {
        successCallback(voteState);
    },function(error) {
        consoledebug.log('GetGroupVote find error is '+ JSON.stringify(error));
        errorCallback(error);
    });
}


/**
 * 获取投票已经投票的人数
 * @param groupID 群ID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(votes); votes 是 {Bmob.Object []} 类数组，通过 votes[x].get(key) 可获取值，
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function GetVoteStateLen(groupID,ID ,successCallback, errorCallback) {
    var Table = Bmob.Object.extend("MakeVoteState");
    var query = new Bmob.Query(Table);
    query.equalTo("groupID",Number(groupID));
    query.equalTo("Id",ID);
    query.count({
    	success:function(count){
    		successCallback(count);
    	},
    	error:function(){
	    	consoledebug.log('GetVoteStateLen find error is '+ JSON.stringify(error));
	        errorCallback(error);
    	}
    });
}


/**
 * 获取投票
 * @param groupID 群ID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(votes); votes 是 {Bmob.Object []} 类数组，通过 votes[x].get(key) 可获取值，
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function GetGroupVote(groupID, successCallback, errorCallback) {
    var Table = Bmob.Object.extend("GroupVote");
    var query = new Bmob.Query(Table);
    query.equalTo("groupID",groupID);
    query.descending("createdAt");
    query.find().then(function(votes) {
        successCallback(votes);
    },function(error) {
        consoledebug.log('GetGroupVote find error is '+ JSON.stringify(error));
        errorCallback(error);
    });
}
/**
 * 获取某个投票
 * @param groupID 群ID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(votes); votes 是 {Bmob.Object []} 类数组，通过 votes[x].get(key) 可获取值，
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function GetOneGroupVote(ID, successCallback, errorCallback) {
    consoledebug.log('GetGroupOneAnnouncement ID is '+ ID);
    var Table = Bmob.Object.extend("GroupVote");
    var query = new Bmob.Query(Table);
   	query.get(ID,function(results){
   		successCallback(results)
   	},function(error){
   		errorCallback(error);
   	})
}

/**
 * 删除投票
 * @param voteID 投票bmob 类中的 id 值
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function deleteGroupVote(voteID, successCallback, errorCallback) {
    var Table = Bmob.Object.extend("GroupVote");
    var query = new Bmob.Query(Table);
    query.equalTo("objectId", voteID);
    query.destroyAll({
        success : function() {
            successCallback();
        },
        error : function(error) {
            consoledebug.log('deleteGroupVote destroyAll error is '+ JSON.stringify(error));
            errorCallback(error);
        }
    });
}


/**
 * 关闭投票
 * @param voteID 投票bmob 类中的 id 值
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function closeGroupVote(voteID,state,successCallback, errorCallback) {
    var myAcount = getMyAccount();
      if (myAcount) {
          var Table = Bmob.Object.extend("GroupVote");
          var query = new Bmob.Query(Table);
          query.equalTo("objectId", voteID);
          query.equalTo("ownerID", myAcount.hhID);
          // 查询所有数据
          query.find({
              success : function(member) {
                  if(member.length > 0){
                      member[0].set('state', state);
                      member[0].save().then(function (member) {
                          successCallback(member);
                      }, errorCallback);
                  }else {
                      err.code = 707;
                      err.message = "No member";
                      errorCallback(err);
                  }
              },
              error : function(error) {
                  errorCallback(error);
              }
          });
      }
}


/**
 * 发布群组活动
 * @param {Object} activityInfo:  bmob对象，公告信息
 * @param {Number} groupID:   //群组ID
 * @param {Number} activityID:   //活动ID
 * @param {Number} ownerID:      //活动发布者ID
 * @param {Object}	count	//显示新活动的个数
  *             }
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function issueGroupActivity(groupID,activityID,activityInfo,ownerRecord, successCallback, errorCallback){
    var myAccount = getMyAccount();
    if (myAccount) {
        var GroupActivity = Bmob.Object.extend("GroupActivity");
        var GroupActivity = new GroupActivity();
        GroupActivity.set("groupID",Number(groupID));
        GroupActivity.set("activityID", activityID);
        GroupActivity.set("ownerID", myAccount.hhID);
        GroupActivity.set("activityInfo", activityInfo);
        GroupActivity.set("ownerRecord", ownerRecord);
        GroupActivity.set("states", 0);
        GroupActivity.save().then(function(GroupActivity) {
            successCallback(GroupActivity);
        }, function(error) {
            consoledebug.log('GroupActivity save error is '+ JSON.stringify(error));
            errorCallback(error);
        });
    }
}


/**
 * 获取群组活动信息
 * @param {Object} activityInfo:  bmob对象，公告信息
 * @param {Number} groupID:   //群组ID
 * @param {Number} activityID:   //活动ID
 * @param {Number} ownerID:      //活动发布者ID
 * @param {Object}	count	//显示新活动的个数
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */

function getGroupActivityInfo(groupID, successCallback, errorCallback){
    var GroupActivity = Bmob.Object.extend("GroupActivity");
    var query = new Bmob.Query(GroupActivity);
    query.descending("createdAt");
    query.equalTo("groupID", groupID);
    query.include("activityInfo");
    query.include("ownerRecord");
    query.find({
        success: function (activityInfo) {
        	consoledebug.log("activityInfo.length is "+activityInfo.length);
        	successCallback(activityInfo);
        },
        error: function (error) {
            errorCallback(error);
        }
    });
}

//@param {Number} status   值：0 已完成  1 已取消  2 进行中
function makeActivityState(status){
	var GroupActivity = Bmob.Object.extend("GroupActivity");
    var query = new Bmob.Query(GroupActivity);
    query.set("status",status);
    query.save();
//  query.save().then(function(record) {
//     successCallback(record);
//  }, function(error) {
//     consoledebug.log('issueAnnouncement save error is '+ JSON.stringify(error));
//     errorCallback(error);
//  });
}



                                
