/**
 * Created by jay on 2015/10/18.
 */

function createSN() {
    return getMyAccount().hhID + (new Date()).Format("yyyyMMddhhmmssS");
}


function WalletTransactions(tables) {
    this.tables = tables;
    this.SN = createSN();
    this.failedTables = [];
}

WalletTransactions.prototype.setAccount = function (account){
    this.account = account;
};

WalletTransactions.prototype.begin = function(accountChange){
    var promise = new Bmob.Promise();
    var obj = this;
    var SN = this.SN;
    getFinanceAccount(function(account){
        if(account.get('walletTransSN') != "0"){
            walletRepair(account, obj.tables, function(account){
                if((account.get('wallet') + accountChange) < 0){
                    var error = {};
                    error.code = 888;
                    error.message = 'wallet insufficient Balance.';
                    promise.reject(error);
                    return;
                }
                obj.account = account;
                account.set('walletTransSN', SN);
                account.set('walletTransChange', accountChange);
                account.save().then(function(acc){
                    promise.resolve(acc);
                },function(error){
                    promise.reject(error);
                });
            }, function(error){
                var error = {};
                error.code = 888;
                error.message = 'the account has been locked';
                promise.reject(error);
            });
            return;
        }
        if((account.get('wallet') + accountChange) < 0){
            var error = {};
            error.code = 888;
            error.message = 'wallet insufficient Balance.';
            promise.reject(error);
            return;
        }
        obj.account = account;
        account.set('walletTransSN', SN);
        account.set('walletTransChange', accountChange);
        account.save().then(function(acc){
            promise.resolve(acc);
        },function(error){
            promise.reject(error);
        });
    },function(error){
        promise.reject(error);
    });
    return promise;
};

WalletTransactions.prototype.commit = function() {
    var account = this.account;
    var accountChange = account.get('walletTransChange');
    var wallet = account.get('wallet');
    account.set('walletTransSN', "0");
    account.set('wallet', wallet + accountChange);
    return account.save();
};

WalletTransactions.prototype.rollback = function() {
    var promises = [];
    var transeSN = this.SN;
    var account = this.account;
    var retryTables = this.failedTables;
    for(var i = 0; i<this.tables.length; i++){
        promises.push( rollbackOneTable(transeSN, this.tables[i], retryTables));
    }
    Bmob.Promise.when(promises).then(function(){
        account.set('walletTransSN', "0");
        account.save();
    },function(error){
        if(retryTables.length > 0){
            var tables = retryTables.concat();
            retryTables.length = 0;
            var retryPromises = [];
            for(var i = 0; i<tables.length; i++){
                retryPromises.push( rollbackOneTable(transeSN, tables[i], retryTables));
            }
            Bmob.Promise.when(retryPromises).then(function(){
                if(retryTables.length == 0){
                    account.set('walletTransSN', "0");
                    account.save();
                }else{
                    consoledebug.log('WalletTransactions rollback failed. ');
                }
            });
        }else{
            account.set('walletTransSN', "0");
            account.save();
        }
    });
};

function rollbackOneTable(SN, tableName, failedTables){
    var Table = Bmob.Object.extend(tableName);
    var query = new Bmob.Query(Table);
    query.equalTo("TransSN", SN);
    // 查询所有数据
    query.find().then(function (results) {
        if(results.length > 0){
            return results[0].destroy();
        }else{
            //var error = {};
            //error.code = 888;
            //error.message = 'cannot rollback by no such SN in table ' + tableName;
            return Bmob.Promise.as();
        }
    },function(error){
        failedTables.push(tableName);
        return Bmob.Promise.error(error);
    });
}

function walletRepair(account, tables, successCallback, errorCallback){
    var promises = [];
    var transeSN = account.get("walletTransSN");
    var retryTables = [];
    for(var i = 0; i<tables.length; i++){
        promises.push( rollbackOneTable(transeSN, tables[i], retryTables));
    }
    Bmob.Promise.when(promises).then(function(){
        account.set('walletTransSN', "0");
        account.set('walletTransChange', "0");
        account.save().then(function(account){
            successCallback(account);
        }, errorCallback);
    },function(error){
        errorCallback(error);
    });
}
/**
 * 获取财务账户信息
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(account); account 是 {Bmob.Object} 类，account.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "wallet", "hCoin"
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function getFinanceAccount(successCallback, errorCallback) {
    var currentUser = getCurrentUser();
    if (currentUser) {
        var Table = Bmob.Object.extend("FinanceAccount");
        var query = new Bmob.Query(Table);
        query.equalTo("hhID", currentUser.get("hhID"));
        // 查询所有数据
        query.find({
            success: function(results) {
                if(results.length > 0){
                    successCallback(results[0]);
                }else {
                    var error = {};
                    error.code = 888;
                    error.message = 'cannot find FinanceAccount by such hhID';
                    errorCallback(error);
                }
            },
            error: function(error) {
                consoledebug.log('getFinanceAccount error is ' + error.message);
                errorCallback(error);
            }
        });
    }
}

/**
 * 新建财务账户
 * @param {Bmob.User} user 登录用户账号
 * @param {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(account); account 是 {Bmob.Object} 类，account.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "wallet", "hCoin"
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function newFinanceAccount(user, successCallback, errorCallback) {
    var Table = Bmob.Object.extend("FinanceAccount");
    var account = new Table();
    account.set("hhID", user.get("hhID"));
    account.set("wallet", 0);
    account.set("hCoin", 1000);
    account.set("walletTransSN", "0");
    account.set("walletTransChange", 0);
    account.set("hCoinTransSN", "0");
    account.set("hCoinTransChange", 0);
    account.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    account.save().then(successCallback, errorCallback);
}

/**
 * 添加钱包充值日志
 * @param {Bmob.User} user 登录信息
 * @param {Object} rechargeInfo 充值金额，包含的key 有：recharge, payer, payerAccount, paymentSN, rechargeTime
 * @param {String} transSN 流水号
 * @param {Number} wallet 充值前钱包余额
 * @return {Bmob.promise}
 * promise callback param:
 *      {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(rechargeJournal); rechargeJournal 是 {Bmob.Object} 类，rechargeJournal.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "recharge", "payer", "payerAccount", "paymentSN", "rechargeTime"
 *      {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function addWalletRechargeJournal(user, rechargeInfo, transSN, wallet){
    var Table = Bmob.Object.extend("WalletRechargeJournal");
    var rechargeJournal = new Table();
    rechargeJournal.set("hhID", user.get("hhID"));
    rechargeJournal.set("recharge", rechargeInfo.recharge);
    rechargeJournal.set("payer", rechargeInfo.payer);
    rechargeJournal.set("payerAccount", rechargeInfo.payerAccount);
    rechargeJournal.set("paymentSN", rechargeInfo.paymentSN);
    rechargeJournal.set("rechargeTime", rechargeInfo.rechargeTime);
    rechargeJournal.set("walletMoney", wallet);
    rechargeJournal.set("TransSN", transSN);
    rechargeJournal.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    return rechargeJournal.save();
}

/**
 * 添加钱包提现日志
 * @param {Bmob.User} user 登录信息
 * @param {Object} walletInfo 充值金额，包含的key 有：withdraw, receipter, receipterAccount, receiptSN, receipterTime
 * @param {String} transSN 流水号
 * @param {Number} wallet 充值前钱包余额
 * @return {Bmob.promise}
 * promise callback param:
 *      {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(rechargeJournal); rechargeJournal 是 {Bmob.Object} 类，rechargeJournal.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "withdraw", "receipter", "receipterAccount", "receiptSN", "receipterTime"
 *      {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function addWalletWithdrawJournal(user, walletInfo, transSN, wallet){
    var Table = Bmob.Object.extend("WalletWithdrawJournal");
    var Journal = new Table();
    Journal.set("hhID", user.get("hhID"));
    Journal.set("withdraw", walletInfo.withdraw);
    Journal.set("receipter", walletInfo.receipter);
    Journal.set("receipterAccount", walletInfo.receipterAccount);
    Journal.set("receiptSN", walletInfo.receiptSN);
    Journal.set("withdrawTime", walletInfo.withdrawTime);
    Journal.set("walletMoney", wallet);
    Journal.set("TransSN", transSN);
    Journal.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    return Journal.save();
}

/**
 * 添加钱包支付日志
 * @param {Bmob.User} user 登录信息
 * @param {Object} paymentInfo 支付信息，包含的key 有：paymentType, payment, orderID, paymentTime
 * @param {String} transSN 流水号
 * @param {Number} wallet 支付前钱包余额
 * @return {Bmob.promise}
 * promise callback param:
 *      {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(rechargeJournal); rechargeJournal 是 {Bmob.Object} 类，rechargeJournal.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "paymentType", "payment", "orderID", "walletMoney", "paymentTime", "TransSN"
 *      {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function addWalletPaymentJournal(user, paymentInfo, transSN, wallet){
    var Table = Bmob.Object.extend("WalletPaymentJournal");
    var paymentJournal = new Table();
    paymentJournal.set("hhID", user.get("hhID"));
    paymentJournal.set("paymentType", paymentInfo.paymentType);
    paymentJournal.set("payment", paymentInfo.payment);
    paymentJournal.set("orderID", paymentInfo.orderID);
    paymentJournal.set("paymentTime", paymentInfo.paymentTime);
    paymentJournal.set("walletMoney", wallet);
    paymentJournal.set("TransSN", transSN);
    paymentJournal.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    return paymentJournal.save();
}

/**
 * 添加钱包收入日志
 * @param {Bmob.User} user 登录信息
 * @param {Object} incomeInfo 支付信息，包含的key 有：incomeType, income, orderID, incomeTime
 * @param {String} transSN 流水号
 * @param {Number} wallet 收入前钱包余额
 * @return {Bmob.promise}
 * promise callback param:
 *      {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(incomeJournal); incomeJournal 是 {Bmob.Object} 类，incomeJournal.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "incomeType", "income", "orderID", "walletMoney", "incomeTime", "TransSN"
 *      {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function addWalletIncomeJournal(user, incomeInfo, transSN, wallet){
    var Table = Bmob.Object.extend("WalletIncomeJournal");
    var journal = new Table();
    journal.set("hhID", user.get("hhID"));
    journal.set("incomeType", incomeInfo.incomeType);
    journal.set("income", incomeInfo.income);
    journal.set("orderID", incomeInfo.orderID);
    journal.set("incomeTime", incomeInfo.incomeTime);
    journal.set("walletMoney", wallet);
    journal.set("TransSN", transSN);
    journal.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    return journal.save();
}

/**
 * 钱包充值
 * @param {Number} payer 充值方式，值为：
 *          1：支付宝，2：微信，3：银联，4：百度钱包
 * @param {Number} payerAccount 充值账户
 * @param {Number} amount 充值金额
 * @param {String} paymentSN 充值账户流水号
 * @param {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(account); account 是 {Bmob.Object} 类，account.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "wallet", "hCoin"
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function walletRecharge(payer, payerAccount, amount, paymentSN, successCallback, errorCallback) {
    var currentUser = getCurrentUser();
    var rollbackTables = ['WalletRechargeJournal'];
    var transe = new WalletTransactions(rollbackTables);
    transe.begin(amount).then(function(account){
        var rechargeInfo = {};
        rechargeInfo.recharge = amount;
        rechargeInfo.payer = payer;
        rechargeInfo.payerAccount = payerAccount;
        rechargeInfo.paymentSN = paymentSN;
        rechargeInfo.rechargeTime = new Date();
        addWalletRechargeJournal(currentUser, rechargeInfo, transe.SN, account.get("wallet")).then(function(rechargeJournal){
            transe.commit().then(successCallback, errorCallback);
        },function(error){
            transe.rollback();
            errorCallback(error);
        });
    },errorCallback);
}

/**
 * 钱包提现
 * @param {Number} receipter 提现收款方，值为：
 *          1：支付宝，2：微信，3：银联，4：百度钱包
 * @param {Number} receipterAccount 提现账户
 * @param {Number} amount 提现金额
 * @param {String} receiptSN 提现账户流水号
 * @param {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(account); account 是 {Bmob.Object} 类，account.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "wallet", "hCoin"
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function walletWithdraw(receipter, receipterAccount, amount, receiptSN, successCallback, errorCallback) {
    var currentUser = getCurrentUser();
    var rollbackTables = ['WalletWithdrawJournal'];
    var transe = new WalletTransactions(rollbackTables);
    transe.begin(0-amount).then(function(account){
        var withdrawInfo = {};
        withdrawInfo.withdraw = amount;
        withdrawInfo.receipter = receipter;
        withdrawInfo.receipterAccount = receipterAccount;
        withdrawInfo.receiptSN = receiptSN;
        withdrawInfo.withdrawTime = new Date();
        addWalletWithdrawJournal(currentUser, withdrawInfo, transe.SN, account.get("wallet")).then(function(withdrawJournal){
            transe.commit().then(successCallback, errorCallback);
        },function(error){
            transe.rollback();
            errorCallback(error);
        });
    },errorCallback);
}

function walletPayment(paymentType, amount, orderID, successCallback, errorCallback){
    var currentUser = getCurrentUser();
    var rollbackTables = ['WalletPaymentJournal'];
    var transe = new WalletTransactions(rollbackTables);
    transe.begin(0 - amount).then(function(account){
        var paymentJournal = {};
        paymentJournal.paymentType = paymentType;
        paymentJournal.payment = amount;
        paymentJournal.orderID = orderID;
        paymentJournal.paymentTime = new Date();
        addWalletPaymentJournal(currentUser, paymentJournal, transe.SN, account.get("wallet")).then(function(paymentJournal){
            transe.commit().then(successCallback, errorCallback);
        },function(error){
            transe.rollback();
            errorCallback(error);
        });
    },errorCallback);
}

function walletIncome(incomeType, amount, orderID, successCallback, errorCallback){
    var currentUser = getCurrentUser();
    var rollbackTables = ['WalletIncomeJournal'];
    var transe = new WalletTransactions(rollbackTables);
    transe.begin(amount).then(function(account){
        var incomeJournal = {};
        incomeJournal.incomeType = incomeType;
        incomeJournal.income = amount;
        incomeJournal.orderID = orderID;
        incomeJournal.incomeTime = new Date();
        addWalletIncomeJournal(currentUser, incomeJournal, transe.SN, account.get("wallet")).then(function(incomeJournal){
            transe.commit().then(successCallback, errorCallback);
        },function(error){
            transe.rollback();
            errorCallback(error);
        });
    },errorCallback);
}


function HCoinTransactions(tables) {
    this.tables = tables;
    this.SN = createSN();
    this.failedTables = [];
}

HCoinTransactions.prototype.begin = function(accountChange){
    var promise = new Bmob.Promise();
    var obj = this;
    var SN = this.SN;
    getFinanceAccount(function(account){
        if(account.get('hCoinTransSN') != "0"){
            hCoinRepair(account, obj.tables, function(account){
                if((account.get('hCoin') + accountChange) < 0){
                    var error = {};
                    error.code = 888;
                    error.message = 'hCoin insufficient Balance.';
                    promise.reject(error);
                    return;
                }
                obj.account = account;
                account.set('hCoinTransSN', SN);
                account.set('hCoinTransChange', accountChange);
                account.save().then(function(acc){
                    promise.resolve(acc);
                },function(error){
                    promise.reject(error);
                });
            }, function(error){
                var error = {};
                error.code = 888;
                error.message = 'the account has been locked';
                promise.reject(error);
            });
            return;
        }
        if((account.get('hCoin') + accountChange) < 0){
            var error = {};
            error.code = 888;
            error.message = 'hCoin insufficient Balance.';
            promise.reject(error);
            return;
        }
        obj.account = account;
        account.set('hCoinTransSN', SN);
        account.set('hCoinTransChange', accountChange);
        account.save().then(function(acc){
            promise.resolve(acc);
        },function(error){
            promise.reject(error);
        });
    },function(error){
        promise.reject(error);
    });
    return promise;
};

HCoinTransactions.prototype.commit = function() {
    var account = this.account;
    var accountChange = account.get('hCoinTransChange');
    var hCoin = account.get('hCoin');
    account.set('hCoinTransSN', "0");
    account.set('hCoin', hCoin + accountChange);
    return account.save();
};

HCoinTransactions.prototype.rollback = function() {
    var promises = [];
    var transeSN = this.SN;
    var account = this.account;
    var retryTables = this.failedTables;
    for(var i = 0; i<this.tables.length; i++){
        promises.push( rollbackOneTable(transeSN, this.tables[i], retryTables));
    }
    Bmob.Promise.when(promises).then(function(){
        account.set('hCoinTransSN', "0");
        account.save();
    },function(error){
        if(retryTables.length > 0){
            var tables = retryTables.concat();
            retryTables.length = 0;
            var retryPromises = [];
            for(var i = 0; i<tables.length; i++){
                retryPromises.push( rollbackOneTable(transeSN, tables[i], retryTables));
            }
            Bmob.Promise.when(retryPromises).then(function(){
                if(retryTables.length == 0){
                    account.set('hCoinTransSN', "0");
                    account.save();
                }else{
                    consoledebug.log('HCoinTransactions rollback failed. ');
                }
            });
        }else{
            account.set('hCoinTransSN', "0");
            account.save();
        }
    });
};

function hCoinRepair(account, tables, successCallback, errorCallback){
    var promises = [];
    var transeSN = account.get("hCoinTransSN");
    var retryTables = [];
    for(var i = 0; i<tables.length; i++){
        promises.push( rollbackOneTable(transeSN, tables[i], retryTables));
    }
    Bmob.Promise.when(promises).then(function(){
        account.set('hCoinTransSN', "0");
        account.set('hCoinTransChange', "0");
        account.save().then(function(account){
            successCallback(account);
        }, errorCallback);
    },function(error){
        errorCallback(error);
    });
}

/**
 * 添加 H 币收入日志
 * @param {Bmob.User} user 登录信息
 * @param {Object} incomeInfo 收入信息，包含的key 有：incomeType, income, orderID, incomeTime
 * @param {String} transSN 流水号
 * @param {Number} hCoin 收入前 h 币余额
 * @return {Bmob.promise}
 * promise callback param:
 *      {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(incomeJournal); incomeJournal 是 {Bmob.Object} 类，incomeJournal.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "incomeType", "income", "orderID", "hCoinMoney", "incomeTime", "TransSN"
 *      {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function addHCoinIncomeJournal(user, incomeInfo, transSN, hCoin){
    var Table = Bmob.Object.extend("hCoinIncomeJournal");
    var journal = new Table();
    journal.set("hhID", user.get("hhID"));
    journal.set("incomeType", incomeInfo.incomeType);
    journal.set("income", incomeInfo.income);
    journal.set("orderID", incomeInfo.orderID);
    journal.set("incomeTime", incomeInfo.incomeTime);
    journal.set("hCoinMoney", hCoin);
    journal.set("TransSN", transSN);
    journal.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    return journal.save();
}

function hCoinIncome(incomeType, amount, orderID, successCallback, errorCallback){
    var currentUser = getCurrentUser();
    var rollbackTables = ['HCoinIncomeJournal'];
    var transe = new HCoinTransactions(rollbackTables);
    transe.begin(amount).then(function(account){
        var incomeJournal = {};
        incomeJournal.incomeType = incomeType;
        incomeJournal.income = amount;
        incomeJournal.orderID = orderID;
        incomeJournal.incomeTime = new Date();
        addHCoinIncomeJournal(currentUser, incomeJournal, transe.SN, account.get("hCoin")).then(function(incomeJournal){
            transe.commit().then(successCallback, errorCallback);
        },function(error){
            transe.rollback();
            errorCallback(error);
        });
    },errorCallback);
}

/**
 * 添加钱包支付日志
 * @param {Bmob.User} user 登录信息
 * @param {Object} paymentInfo 支付信息，包含的key 有：paymentType, payment, orderID, paymentTime
 * @param {String} transSN 流水号
 * @param {Number} wallet 支付前钱包余额
 * @return {Bmob.promise}
 * promise callback param:
 *      {function} successCallback 成功后回调函数，定义为 .
 * 		successCallback(rechargeJournal); rechargeJournal 是 {Bmob.Object} 类，rechargeJournal.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "paymentType", "payment", "orderID", "walletMoney", "paymentTime", "TransSN"
 *      {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function addhCoinPaymentJournal(user, paymentInfo, transSN, hCoin){
    var Table = Bmob.Object.extend("HCoinPaymentJournal");
    var paymentJournal = new Table();
    paymentJournal.set("hhID", user.get("hhID"));
    paymentJournal.set("paymentType", paymentInfo.paymentType);
    paymentJournal.set("payment", paymentInfo.payment);
    paymentJournal.set("orderID", paymentInfo.orderID);
    paymentJournal.set("paymentTime", paymentInfo.paymentTime);
    paymentJournal.set("hCoinMoney", hCoin);
    paymentJournal.set("TransSN", transSN);
    paymentJournal.setACL(new Bmob.ACL(user));
    //添加数据，第一个入口参数是null
    return paymentJournal.save();
}

function hCoinPayment(paymentType, amount, orderID, successCallback, errorCallback){
    var currentUser = getCurrentUser();
    var rollbackTables = ['HCoinPaymentJournal'];
    var transe = new HCoinTransactions(rollbackTables);
    transe.begin(0 - amount).then(function(account){
        var paymentJournal = {};
        paymentJournal.paymentType = paymentType;
        paymentJournal.payment = amount;
        paymentJournal.orderID = orderID;
        paymentJournal.paymentTime = new Date();
        addhCoinPaymentJournal(currentUser, paymentJournal, transe.SN, account.get("hCoin")).then(function(paymentJournal){
            transe.commit().then(successCallback, errorCallback);
        },function(error){
            transe.rollback();
            errorCallback(error);
        });
    },errorCallback);
}