/**
 * 接口说明：sapotenAjaxRequest('pay/create', 'POST', payment, successcallback, errorcallback)
 * 渠道支付流程
 * @param {Object} payment: 支付信息
 * 包含的属性 为：{
 *              order_no: String,        ////订单编号，8-20位
 *              amount: Number,         //支付金额
 *              subject: String,        //商品名称
 *              body: String,        //商品描述
 *              channel: String,        //支付渠道，由  ping++ 定义
                                                                                                支付通道，取值范围:
                                alipay:支付宝手机支付
                                alipay_wap:支付宝手机网页支付
                                alipay_qr:支付宝扫码支付
                                alipay_pc_direct:支付宝 PC 网页支付
                                apple_pay:Apple Pay
                                bfb:百度钱包移动快捷支付
                                bfb_wap:百度钱包手机网页支付
                                upacp:银联全渠道支付（2015 年 1 月 1 日后的银联新商户使用。若有疑问，请与 Ping++ 或者相关的收单行联系）
                                upacp_wap:银联全渠道手机网页支付（2015 年 1 月 1 日后的银联新商户使用。若有疑问，请与 Ping++ 或者相关的收单行联系）
                                upacp_pc:银联 PC 网页支付
                                upmp:银联手机支付（限个人工作室和 2014 年之前的银联老客户使用。若有疑问，请与 Ping++ 或者相关的收单行联系）
                                upmp_wap:银联手机网页支付（限个人工作室和 2014 年之前的银联老客户使用。若有疑问，请与 Ping++ 或者相关的收单行联系）
                                wx:微信支付
                                wx_pub:微信公众账号支付
                                wx_pub_qr:微信公众账号扫码支付
                                yeepay_wap:易宝手机网页支付
                                jdpay_wap:京东手机网页支付
                                cnp_u:应用内快捷支付（银联）
                                cnp_f:应用内快捷支付（外卡)
 *              description: String,        //订单附加说明，最多 255 个 Unicode 字符。
 *              extraBmobData：String,        //跟平台相关的额外数据，object 转String。具体说明见具体支付类型
  *             }
 * @param {function} successCallback 成功后回调函数，定义为 .
 *      successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 *      errCallback(error); error {String} 取值为 success, cancel, fail， error
 */

function sapotenAjaxRequest(url, method, bodyParam, callBack) {
    var rsa = new RSAKey();
    rsa.setPublic("d20692b305ca8065da9084e8b7b6a9f9d2e75eb48d115452b0d55c9a390d0821\n7a2af7954c89c65256b7889fc18751ccd33f0f2096fc808acb9a0a18e1108be9\n18769a059046f12952875d24092db2ad221fe264332951471a36d515dccf82a7\n1d6789d78490b8d229da022c005e4ce6a8a2658599679d318f05b1968a29d287", '10001');
    if(bodyParam.token){
        var encodeData = {
            token:bodyParam.token,
            TransSN:bodyParam.TransSN
        }
        var res = rsa.encrypt(JSON.stringify(encodeData)); 
        var base64Cipher = hex2b64(res);
        consoledebug.log('sapotenAjaxRequest encrypt is : '+ base64Cipher);
        delete bodyParam.token;
        delete bodyParam.TransSN;
        bodyParam.cipher = base64Cipher;
    }
    consoledebug.log('sapotenAjaxRequest bodyParam is : '+ JSON.stringify(bodyParam));

    var common_url = 'https://'+ bdAddress +'/app/Owl/1/';
    api.ajax({
        url: common_url + url,
        method: method,
        timeout: 60,
        headers: {
            "Content-type": "application/json;charset=UTF-8",
        },
        data: {
            body: bodyParam
        }
    }, function (ret, err) {
        consoledebug.log('sapotenAjaxRequest ret is : '+ JSON.stringify(ret));
        consoledebug.log('sapotenAjaxRequest err is : '+ JSON.stringify(err));
        if(!err){
            refreashWallet();
        }
        callBack(ret, err);
    });
}

function paymentErrorMessage(code){
	var message = "";
	switch(code){
		case 602:
			message = "账户余额不足";
		break;
		case 603:
			message = "支付金额与记录不匹配";
		break;
        case 604:
            message = "支付时间模式不对";
        break;
        case 605:
            message = "订单状态不对";
        break;
		default:
            message = "支付出错，请稍后重试";
		break;
	}
	return message;
}

/**
 * 获取财务账户信息
 *
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(account); account 是 {Bmob.Object} 类，account.get(key) 可获取值，
 * 		可用的 key 有 "hhID", "wallet" (单位： 分), "hCoin"
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errorCallback(error); error is a class, {code: number, message:string}
 */
function getFinanceAccount(hhID, successCallback, errorCallback) {
	var Table = Bmob.Object.extend("FinanceAccount");
	var query = new Bmob.Query(Table);
	query.equalTo("hhID", hhID);
	query.select("hhID","wallet","hCoin");
	// 查询所有数据
	query.find({
		success : function(results) {
			if (results.length > 0) {
				successCallback(results[0]);
			} else {
				var error = {};
				error.code = 888;
				error.message = 'cannot find FinanceAccount by such hhID';
				errorCallback(error);
			}
		},
		error : function(error) {
			consoledebug.log('getFinanceAccount error is ' + error.message);
			errorCallback(error);
		}
	});
}

function signInIncome(){
}

//生成订单支付的参数
//function bmobOrderPaymentParam(paymentInfo) {
//  var currentUser = Bmob.User.current();
//  if (currentUser) {
//      var token = currentUser._sessionToken;
//  }
//  var hhID = getMyAccount().hhID;
//  var TransSN = paymentInfo.paymentID;
//  var payInfo = {
//      "token" : token,
//      "ownerID" : hhID,
//      "TransSN" : TransSN,
//      "orderID" : paymentInfo.orderID,
//      "orderType" : 1 //1为互助，2为活动，3为参与活动，4为虚拟币充值
//  };
//  
//  return payInfo;
//}


//生成订单支付的参数
function bmobWallteRechargeParam(rechargeTrans, ownerID) {
    var currentUser = Bmob.User.current();
    var userId, token;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : ownerID,
        "receiverID" : ownerID,
        "TransSN" : rechargeTrans
    };
    
    return payInfo;
}
//生成订单支付的参数
function bmobWallteRechargeCancelParam(rechargeTrans, ownerID) {
    var currentUser = Bmob.User.current();
    var userId, token;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var payInfo = {
        "token" : token,
        "ownerID" : ownerID,
        "TransSN" : rechargeTrans,
        "operation":"cancel",     //done, cancel
    };
    
    return payInfo;
}

//生成订单支付的参数
//function bmobHCoinPaymentParam(paymentInfo) {
//  var currentUser = Bmob.User.current();
//  if (currentUser) {
//      var token = currentUser._sessionToken;
//  }
//  var hhID = getMyAccount().hhID;
//  var TransSN = paymentInfo.paymentID;
//  var payInfo = {
//      "token" : token,
//      "ownerID" : hhID,
//      "TransSN" : TransSN,
//      "orderID" : paymentInfo.orderID,
//      "orderType" : 4 //1为互助，2为活动，3为参与活动，4为虚拟币充值
//  };
//  
//  return payInfo;
//}

/**
 * 渠道支付流程
 * @param {Object} paymentInfo: 支付信息
 * 包含的属性 为：{
        "amount":Number,    //支付金额
        "channel":String,    //支付渠道，见 ping ++ 定义
        }
 * @param {function} successCallback 成功后回调函数，定义为 .
 *      successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 *      errCallback(error); error {String} 取值为 success, cancel, fail， error
 */
function walletRechargePay(paymentInfo, successCallback, errorCallback) {
    consoledebug.log('channelPay paymentInfo is : ' + JSON.stringify(paymentInfo));
    var myAccount = getMyAccount();
    var rechargeTrans = 'c' + myAccount.hhID + (new Date()).Format("yyMMddhhmmss");
    var pingppParam = {
      "order_no":(new Date()).Format("yyMMddhhmmss"),  //订单编号，8-20位
      "amount": parseInt(paymentInfo.amount),  //支付金额
      "subject":paymentInfo.subject, //商品名称
      "body":myAccount.hhID + " recharge",
      "description":rechargeTrans,
      "channel":paymentInfo.channel
    }
    var payment = bmobWallteRechargeParam(rechargeTrans, myAccount.hhID);
    payment.pingppParam = pingppParam;
    sapotenAjaxRequest('pay/rechargeCreate', 'POST', payment, function(ret, err) {
        if (ret && ret.state == 1) {
            var pingpp = api.require('pingpp');
            var params = {
                charge : JSON.stringify(ret.charge),
                //scheme: "yourappurlscheme"
            };
            pingpp.createPayment(params, function(ret, err) {
                consoledebug.log('pingpp createPayment ret is : ' + JSON.stringify(ret));
                //ret.result 可能的值是 success, cancel, fail
                if (ret.result == "success") {
                    successCallback();
                } else if (ret.result == "cancel") {
                    var cancelParam = bmobWallteRechargeCancelParam(rechargeTrans, myAccount.hhID);
                    baeWalletRechargeCancel(cancelParam, function() {
                        errorCallback(ret.result);
                    }, function(error) {
                        consoledebug.log('bmobPaymentCancel error is : ' + JSON.stringify(error));
                        errorCallback(ret.result);
                    })
                } else {
                    errorCallback(ret.result);
                }
            });
        } else {
            errorCallback("error");
        }
    })
}


/**
 * 真实货币支付流程
 * @param {Number} peyMethod: 支付方式， 1：钱包，2：支付宝，3：微信
 * @param {Object} paymentInfo: 支付信息
 * 包含的属性 为：{
        "amount":Number,    //支付金额
        "orderID":Number,       //支付相关联的订单ID
        "orderType":Number,  //1为互助，2为活动，3为参与活动，4为虚拟币充值
        "paymentID":String,    //支付流水号，transSN
        }
 * @param {function} successCallback 成功后回调函数，定义为 .
 *      successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 *      errCallback(error); error {String} 取值为 success, cancel, fail， error
 */
function bmobWalletPay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "amount":parseInt(paymentInfo.amount),
        "orderID":paymentInfo.orderID,
        "orderType":paymentInfo.orderType
    };
    consoledebug.log("bmobWalletPay payInfo is " + JSON.stringify(payInfo));
    Bmob.Cloud.run('PersonalWalletPay', payInfo, {
        success : function(result) {
            consoledebug.log("bmobWalletPay orderWalletPay result is " + JSON.stringify(result));
            var resultObj = JSON.parse(result);
            if(resultObj.code == 0){
                successCallback(TransSN);
            }else{
                errorCallback("error");
            }
        },
        error : function(error) {
            consoledebug.log("bmobWalletPay orderWalletPay error is " + JSON.stringify(error));
            errorCallback("error");
        }
    })
}
function baeWalletPay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "amount":parseInt(paymentInfo.amount),		//必须要取整，有时 js 计算结果会莫名带上小数，防止计算出问题
        "orderID":paymentInfo.orderID,
        "orderType":paymentInfo.orderType
    };
    if(paymentInfo.orderType == 2){
    	payInfo.appraisement = paymentInfo.appraisement
    }
    if(paymentInfo.orderType == 5){
    	payInfo.selectList = paymentInfo.selectList
    }
    consoledebug.log("baeWalletPay payInfo is " + JSON.stringify(payInfo));
    sapotenAjaxRequest('finance/PersonalWalletPay', 'POST', payInfo, function(ret, err) {
        if(!err){
            if(ret && ret.code == 0){
                successCallback(TransSN);
                return;
            }else{
                errorCallback(ret);
                return;
            }
        }
        err.ret = ret;
        consoledebug.log("baeWalletPay PersonalWalletPay err is " + JSON.stringify(err));
        errorCallback(err);
    })
}

/**
 * 担保资金支付请求
 * @param {Object} paymentInfo: 支付信息
 * 包含的属性 为：{
*              paymentType: Number,        //请求支付类型，1：互助取消退款，2：互助完成付款，3：活动取消付款，4：活动完成付款
*              paymentID: String,        //事物流水号
*              orderID: Number        //活动或互助的订单ID
        }
 * @param {function} successCallback 成功后回调函数，定义为 .
 *      successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 *      errCallback(error); error {String} 取值为 success, cancel, fail， error
 */
function bmobGuaranteePay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "paymentType":paymentInfo.paymentType,
        "orderID":paymentInfo.orderID
    };
    consoledebug.log("bmobGuaranteePay payInfo is " + JSON.stringify(payInfo));
    Bmob.Cloud.run('GuaranteePayRequest', payInfo, {
        success : function(result) {
            consoledebug.log("bmobGuaranteePay GuaranteePayRequest result is " + JSON.stringify(result));
            var resultObj = JSON.parse(result);
            if(resultObj.code == 0){
                successCallback(TransSN);
            }else{
                errorCallback("error");
            }
        },
        error : function(error) {
            consoledebug.log("bmobGuaranteePay GuaranteePayRequest error is " + JSON.stringify(error));
            errorCallback("error");
        }
    })
}
function baeGuaranteePay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "paymentType":paymentInfo.paymentType,
        "orderID":paymentInfo.orderID
    };
    if(paymentInfo.paymentType == 4){
    	payInfo.appraisement = paymentInfo.appraisement;
    }else if(paymentInfo.paymentType == 5){
        payInfo.selectList = paymentInfo.selectList;
    }
    consoledebug.log("bmobGuaranteePay payInfo is " + JSON.stringify(payInfo));
    sapotenAjaxRequest('finance/GuaranteePayRequest', 'POST', payInfo, function(ret, err) {
        if(!err){
            if(ret && ret.code == 0){
                successCallback(TransSN);
                return;
            }else{
                errorCallback(ret);
                return;
            }
        }
        err.ret = ret;
        consoledebug.log("baeGuaranteePay GuaranteePayRequest err is " + JSON.stringify(err));
        errorCallback(err);
    })
}



/**
 * 平台虚拟币支付请求
 * @param {Object} paymentInfo: 支付信息
 * 包含的属性 为：{
*              paymentType: Number,        //请求支付类型，1：签到奖励，2：系统任务奖励，3：互助报名退出退款，4：互助取消退款，5：落选退款
*              paymentID: String,        //事物流水号
*              orderID: Number        //活动或互助的订单ID
        }
 * @param {function} successCallback 成功后回调函数，定义为 .
 *      successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 *      errCallback(error); error {String} 取值为 success, cancel, fail， error
 */
function bmobPlatformHCoinPay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "paymentType":paymentInfo.paymentType,
        "orderID":paymentInfo.orderID
    };
    consoledebug.log("bmobPlatformHCoinPay payInfo is " + JSON.stringify(payInfo));
    Bmob.Cloud.run('PlatformHCoinPayRequest', payInfo, {
        success : function(result) {
            consoledebug.log("bmobPlatformHCoinPay PlatformHCoinPayRequest result is " + JSON.stringify(result));
            var resultObj = JSON.parse(result);
            if(resultObj.code == 0){
                successCallback(TransSN);
            }else{
                errorCallback("error");
            }
        },
        error : function(error) {
            consoledebug.log("bmobPlatformHCoinPay PlatformHCoinPayRequest error is " + JSON.stringify(error));
            errorCallback("error");
        }
    })
}
function baePlatformHCoinPay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "paymentType":paymentInfo.paymentType,
        "orderID":paymentInfo.orderID
    };
    consoledebug.log("bmobPlatformHCoinPay payInfo is " + JSON.stringify(payInfo));
    sapotenAjaxRequest('finance/PlatformHCoinPayRequest', 'POST', payInfo, function(ret, err) {
        if(!err){
            if(ret && ret.code == 0){
                successCallback(TransSN);
                return;
            }else{
                errorCallback(ret);
                return;
            }
        }
        err.ret = ret;
        consoledebug.log("baePlatformHCoinPay PlatformHCoinPayRequest err is " + JSON.stringify(err));
        errorCallback(err);
    })
}



/**
 * 虚拟币支付请求
 * @param {Object} paymentInfo: 支付信息
 * 包含的属性 为：{
*              paymentType: Number,        //1报名费、2取消任务手续费
*              paymentID: String,        //事物流水号
*              orderID: Number        //活动或互助的订单ID
        	   orderType:Number,  //1为互助，2为活动，3为参与活动，4为虚拟币充值
        }
 * @param {function} successCallback 成功后回调函数，定义为 .
 *      successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 *      errCallback(error); error {String} 取值为 success, cancel, fail， error
 */
function bmobEnrollHCoinPay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "amount":parseInt(paymentInfo.amount),
        "orderID":paymentInfo.orderID,
        "orderType":1,
        "paymentType":1   //1报名费、2取消任务手续费
    };
    consoledebug.log("bmobEnrollHCoinPay payInfo is " + JSON.stringify(payInfo));
    Bmob.Cloud.run('PersonalHCoinPay', payInfo, {
        success : function(result) {
            consoledebug.log("bmobEnrollHCoinPay PersonalHCoinPay result is " + JSON.stringify(result));
            var resultObj = JSON.parse(result);
            if(resultObj.code == 0){
                successCallback(TransSN);
            }else{
                errorCallback(resultObj);
            }
        },
        error : function(error) {
            consoledebug.log("bmobEnrollHCoinPay PersonalHCoinPay error is " + JSON.stringify(error));
            errorCallback("error");
        }
    })
}
function baeEnrollHCoinPay(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "amount":parseInt(paymentInfo.amount),
        "orderID":paymentInfo.orderID,
        "orderType":1,
        "paymentType":paymentInfo.paymentType   //1报名费、2取消任务手续费、3秀场订单的报名
    };
    if(paymentInfo.recharge != undefined){
    	payInfo.recharge = paymentInfo.recharge;
    }
    consoledebug.log("bmobEnrollHCoinPay payInfo is " + JSON.stringify(payInfo));
    sapotenAjaxRequest('finance/PersonalHCoinPay', 'POST', payInfo, function(ret, err) {
        if(!err){
            if(ret && ret.code == 0){
                successCallback(TransSN);
                return;
            }else{
                errorCallback(ret);
                return;
            }
        }
        err.ret = ret;
        consoledebug.log("baeEnrollHCoinPay PersonalHCoinPay err is " + JSON.stringify(err));
        errorCallback(err);
    })
}


function bmobWalletRechargeCancel(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = paymentInfo.paymentID;
    var payInfo = {
        "token" : token,
        "userID" : userId,
        "ownerID" : hhID,
        "TransSN" : TransSN,
        "operation": "cancel",     //done, cancel
        "paymentTime" : new Date() //
    };

    Bmob.Cloud.run('WalletRechargeDone', payInfo, {
        success : function(result) {
            consoledebug.log("bmobPaymentDone orderPaymentDone result is " + JSON.stringify(result));
            var resultObj = JSON.parse(result);
            if(resultObj.code == 0){
                successCallback(TransSN);
            }else{
                errorCallback(resultObj);
            }
        },
        error : function(error) {
            consoledebug.log("bmobPaymentDone orderPaymentDone error is " + JSON.stringify(error));
            errorCallback(error);
        }
    })
}
function baeWalletRechargeCancel(paymentInfo, successCallback, errorCallback) {
    sapotenAjaxRequest('pay/rechargeCancel', 'POST', paymentInfo, function(ret, err) {
        if(!err){
            if(ret && ret.code == 0){
                successCallback();
                return;
            }else{
                errorCallback(ret);
                return;
            }
        }
        err.ret = ret;
        consoledebug.log("baeWalletRechargeCancel rechargeCancel err is " + JSON.stringify(err));
        errorCallback(err);
    })
}


function baePersonalWithdraw(paymentInfo, successCallback, errorCallback) {
    var currentUser = Bmob.User.current();
    var token;
    var userId;
    if (currentUser) {
        token = currentUser._sessionToken;
        userId = currentUser.id;
    }
    var hhID = getMyAccount().hhID;
    var TransSN = (hhID + '') + ((new Date()).getTime() + '');;
    var payInfo = {
        "token" : token,
        //"userID" : userId,
        "TransSN" : TransSN,
        "ownerID" : hhID,
        "amount":parseInt(paymentInfo.amount),
        "wxOpenid":paymentInfo.openid,
		"unionid": paymentInfo.unionid
    };
    consoledebug.log("baeWalletPay payInfo is " + JSON.stringify(payInfo));
    sapotenAjaxRequest('pay/wxWithdrawCreate', 'POST', payInfo, function(ret, err) {
        if(!err){
            if(ret && ret.code == 0){
                successCallback();
                return;
            }else{
                errorCallback(ret);
                return;
            }
        }
        err.ret = ret;
        consoledebug.log("baeWalletPay PersonalWalletPay err is " + JSON.stringify(err));
        errorCallback(err);
    })
}

function refreashWallet() {
//	api.execScript({
//		name : 'root',
//		frameName : 'user',
//		script : "freashPersonalCenter()"
//	});
}
