
/**
 * 发布留言
 * @param {Object} messageInfo:  类对象，留言信息
 * 包含的属性 为：{
   *            ownerID: String.        //发布留言者hhID
 *              photo: [],        //标题
 *              content: String,        //内容
 * 				location				//位置
 * 				geo            			//经纬度
  *             }
 *@param {Bmob.Object} ownerRecord: 用户信息的 bmob 对象
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function issuePostMessageInfo(messageInfo,successCallback, errorCallback){
	var myAccount = getMyAccount();
	if (myAccount) {
		var bMap = api.require('bMap');
		bMap.getLocation({
			accuracy : '100m',
			autoStop : true,
			filter : 1
		}, function(ret, err) {
			if (ret.status) {
				var point = new Bmob.GeoPoint({latitude: ret.lat, longitude: ret.lon});
				bMap.getNameFromCoords({
					lon : ret.lon,
					lat : ret.lat
				}, function(ret, err) {
					if (ret.status) {
						var address = ret.address;
						var UserInfo = Bmob.Object.extend("UserInfo");
					    var userInfoRecord = new UserInfo();
					    userInfoRecord.id = myAccount.userInfoId;
					    
						var PostMessageInfo = Bmob.Object.extend("PostMessageInfo");
					    var PostMessageInfo = new PostMessageInfo();
					    PostMessageInfo.set("ownerID", myAccount.hhID);
					    PostMessageInfo.set("content", messageInfo.content);
					    PostMessageInfo.set("location", address);
					    PostMessageInfo.set("geo", point);
	    				PostMessageInfo.set("reportNum", 0);
					    PostMessageInfo.set("ownerInfo", userInfoRecord);
					    PostMessageInfo.set("commentCount", 0);
					    PostMessageInfo.save().then(function(messageInfo){
					    	successCallback(messageInfo);
					    },function(error){
					    	errorCallback(error)
					    })
					}else{
						errorCallback(err)
					}
				});
			}else {
				errorCallback(err)
			}
		});
	}else{
		errorCallback()
	}
}

/**
 * 删除留言
 *@param {Bmob.Object} ownerRecord: 用户信息的 bmob 对象
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function delMessageInfo(hhID,commentID,successCallback, errorCallback){
	var PostMessageInfo = Bmob.Object.extend("PostMessageInfo");
    var PostMessageInfo = new PostMessageInfo();
	PostMessageInfo.id = commentID;
	PostMessageInfo.destroy({
		success : function() {
            var MessagePhotos = Bmob.Object.extend("MessagePhotos");
			var MessagePhotos = new Bmob.Query(MessagePhotos);
			MessagePhotos.equalTo("ownerID", hhID);
			MessagePhotos.equalTo("messageID", commentID);
			MessagePhotos.destroyAll({
				success : function() {
		            successCallback();
				},
				error : function(error) {
					consoledebug.log('deleteHelpOrder Active error is '+ JSON.stringify(error));
		            errorCallback(error);
				}
			});
		},
		error : function(error) {
			consoledebug.log('deleteHelpOrder Active error is '+ JSON.stringify(error));
            errorCallback(error);
		}
	});
}

/**
 * 删除评论
 *@param {Bmob.Object} ownerRecord: 用户信息的 bmob 对象
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function delCommonInfo(objID,successCallback, errorCallback){
	var PostComment = Bmob.Object.extend("PostComment");
    var PostComment = new PostComment();
    PostComment.id = objID;
	PostComment.destroy({
		success : function() {
            successCallback();
		},
		error : function(error) {
			consoledebug.log('deleteHelpOrder Active error is '+ JSON.stringify(error));
            errorCallback(error);
		}
	});
}

/**
 * 举报某一留言
 *@param {Bmob.Object} ownerRecord: 用户信息的 bmob 对象
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function reportMessage(informerID,reportInfo,successCallback, errorCallback){
	consoledebug.log('reportMessage informerID reportInfo is '+ informerID+" "+JSON.stringify(reportInfo));
	var ReportMessageInfo = Bmob.Object.extend("ReportMessageInfo");
	var reportMessageInfo = new ReportMessageInfo();
	//举报者hhID
	reportMessageInfo.set("informerID", informerID);
	reportMessageInfo.set("targetID", reportInfo.ownerID);
	reportMessageInfo.set("ID", reportInfo.ID);
	reportMessageInfo.save().then(function(result) {
		consoledebug.log('reportMessage result is '+ JSON.stringify(result));
        successCallback(result);
	}, function(error) {
        errorCallback(error);
	});
}
//修改被举报的次数
function changeReportNum(objID,reportNum,successCallback, errorCallback){
	var PostMessageInfo = Bmob.Object.extend("PostMessageInfo");
	var PostMessageInfo = new PostMessageInfo();
    PostMessageInfo.id = objID;
    PostMessageInfo.set("reportNum",reportNum)
	PostMessageInfo.save().then(function(result) {
        successCallback(result);
	},function(error) {
        errorCallback(error);
	});
}
/**
 * 保存图片
 * @param {Object} messagePhotos:  类对象，留言信息
 * 包含的属性 为：{
   *            ownerID: String.        //发布留言者hhID
 *              messageOphoto: String,        //原始图片
 * 				messageTphoto: String,		//缩略图
 * 				messageID            			
  *             }
 *@param {Bmob.Object} photos: 发布留言的图片信息 bmob 对象
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback();
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
function insertMessageOnePhotosRecord(messageInfo,messagePhotos,successCallback, errorCallback){
	var MessagePhotos = Bmob.Object.extend("MessagePhotos");
	var MessagePhotos = new MessagePhotos();
	consoledebug.log("messagePhotos.hhID is " + messagePhotos.hhID)
	MessagePhotos.set("ownerID", messagePhotos.hhID);
	MessagePhotos.set("ownerID", messageInfo.get("ownerID"));
	MessagePhotos.set("messageID", messageInfo.id);
	MessagePhotos.set("messageOphoto", messagePhotos.messageOphoto);
	MessagePhotos.set("messageTphoto", messagePhotos.messageTphoto);
	MessagePhotos.save().then(function(photos){
	   successCallback(photos);
	},function(error){
	   errorCallback(error)
	})
}


function insertMessageMorePhotosRecord(messageInfo,messagePhotos){
	consoledebug.log("saveMessagePhotos2 messageInfo is" + JSON.stringify(messageInfo));
	var promise = new Bmob.Promise();
		saveMessagePhoto(messagePhotos, 128, 128,2, function(Ophoto, Tphoto) {
			var messagePhotos = {};
			messagePhotos.messageOphoto = Ophoto;
			messagePhotos.messageTphoto = Tphoto;
			var MessagePhotos = Bmob.Object.extend("MessagePhotos");
			var MessagePhotos = new MessagePhotos();
			MessagePhotos.set("ownerID", messageInfo.get("ownerID"));
			MessagePhotos.set("messageID", messageInfo.id);
			MessagePhotos.set("messageOphoto", messagePhotos.messageOphoto);
			MessagePhotos.set("messageTphoto", messagePhotos.messageTphoto);
			MessagePhotos.save().then(function(photos){
				consoledebug.log("photos is" + JSON.stringify(photos));
				promise.resolve(photos);
			},function(error){
			  	promise.reject(error);
			});
		}, function(error) {
			 promise.reject(error);
			consoledebug.log("getMessagePhotos saveMessagePhoto error is" + JSON.stringify(error));
		})
	
	return promise;
}

function updatePostMessage(ID, successCallback, errorCallback){
	var PostMessageInfo = Bmob.Object.extend("PostMessageInfo");
	var postRecord = new PostMessageInfo();
	postRecord.id = ID;
	postRecord.increment("commentCount");
	postRecord.save().then(successCallback, errorCallback); 
}
/**
 * 生成留言首页的查询条件
 * 查询方式为：先查3公里内的求助信息，以订单发布时间排序，后续再按照2公里范围向外扩张，每个区域内订单仍按订单发布时间排序。
 * 距离最大扩张到50公里。查询是分页查询，每次更新 SKIP_NUMBER 个数据
 *
 */

function makePostMessageQuery(gQueryerHhID, condition) {
	var ShieldQuery = Bmob.Object.extend("ShieldQuery");
	var shieldQuery = new Bmob.Query(ShieldQuery);
	shieldQuery.equalTo("ownerID", gQueryerHhID);

	var Table = Bmob.Object.extend("PostMessageInfo");
	var query = new Bmob.Query(Table);

//		    query.withinKilometers("geo", condition, 80);
	query.withinKilometers("geo", condition.geo, 80);

	//		var date = new Date();
	//		var date2 = date.getTime() - 2*24*60*60*1000;	//2天之前的时间
	//		date.setTime(date2);
	//	    consoledebug.log('getNearbyUser date is ' + date.toString());
	//		query.greaterThan("updatedAt", date);
	query.lessThanOrEqualTo("reportNum", REPORT_NUMBER);
	query.doesNotMatchKeyInQuery("ownerID", "targetID", shieldQuery);
	query.descending("createdAt");
	query.include("ownerInfo");
	query.limit(SKIP_NUMBER);
	
	return query;
}

/**
 * 获取留言列表
 * @param hhID 发布人hhID
 * @param {function} successCallback 成功获取朋友列表后回调函数，定义为 .
 * 		successCallback(postmessage); announcements 是 {Bmob.Object []} 类数组，通过 announcements[x].get(key) 可获取值，
 * 		可用的 key 有 ownerID,content,photo,
 * @param {function} errorCallback 操作失败后回调函数，定义为：
 * 		errCallback(error); error is a class, {code: number, message:string}
 */
var SKIP_NUMBER = 5;
var REPORT_NUMBER = 3;
var gPostMessageQuery;
var gPostMessageGetAllNum = 0;
var gCondition = {};
var gQueryerHhID;
var gPostMessageNewQuery;
var gPostMessageGetNewAllNum = 0;
function GetPostMessage(successCallback, errorCallback) {
	gPostMessageNewQuery = null;
	gPostMessageGetNewAllNum = 0;
	updateLocation(function(location){
		consoledebug.log("GetPostMessage location is  "+JSON.stringify(location));
		gCondition.geo = location;
		gQueryerHhID = getMyAccount().hhID
		
		var query = makePostMessageQuery(gQueryerHhID, gCondition)
		
		gPostMessageQuery = query;
		gPostMessageGetAllNum = 0;
		
	    query.find().then(function(postmessage) {
	    	consoledebug.log("GetPostMessage postmessage is "+postmessage.length+" "+JSON.stringify(postmessage));
	        if(postmessage.length >= SKIP_NUMBER) {
                gPostMessageGetAllNum += postmessage.length;
                successCallback(postmessage);
            }else{
                GetPostMessageNext(successCallback, errorCallback);
            }
	    },function(error){
	        errorCallback(error);
	    });
	},function(error){
	})
}
 
/**
 * 获取留言列表的下一页，GetPostMessage 方法配套使用
 * @param foundOrders 是 {Bmob.Object[]} 类数组，包含了上一步已经查找到的数据，但是数量不够，需要继续查找数据补充
 */
function GetPostMessageNext(successCallback, errorCallback){
	if(gPostMessageQuery){
	    gPostMessageQuery.skip(gPostMessageGetAllNum);
	    gPostMessageQuery.include("ownerInfo");	//每次重新find 时都需要再设置此值
	    gPostMessageQuery.limit(SKIP_NUMBER);
	    gPostMessageQuery.find().then(function(postmessage){
	    	consoledebug.log("GetPostMessageNext postmessage is "+JSON.stringify(postmessage));
	    	if(postmessage.length == 0){
	    		var Table = Bmob.Object.extend("PostMessageInfo");
	    		var newQuery = new Bmob.Query(Table);
	    		var ShieldQuery = Bmob.Object.extend("ShieldQuery");
				var shieldQuery = new Bmob.Query(ShieldQuery);
				shieldQuery.equalTo("ownerID", gQueryerHhID);
				newQuery.lessThanOrEqualTo("reportNum", REPORT_NUMBER);
				newQuery.doesNotMatchKeyInQuery("ownerID", "targetID", shieldQuery);
				newQuery.descending("createdAt");
				newQuery.include("ownerInfo");
				newQuery.limit(SKIP_NUMBER);
	    		newQuery.doesNotMatchKeyInQuery("messageID", "messageID", gPostMessageQuery);
	    		gPostMessageQuery = null;
	    		gPostMessageNewQuery = newQuery;
	    		gPostMessageNewQuery.find().then(function(postmessage){
			    	if(postmessage.length == 0){
			    		errorCallback();
			    	}else{
			    		gPostMessageGetNewAllNum += postmessage.length;
			        	successCallback(postmessage);
			    	}
			    },errorCallback);
	    	}else{
	    		gPostMessageGetAllNum += postmessage.length;
	        	successCallback(postmessage);
	    	}
	    },errorCallback);
    }else if(gPostMessageNewQuery){
    	gPostMessageNewQuery.skip(gPostMessageGetNewAllNum);
	    gPostMessageNewQuery.include("ownerInfo");	//每次重新find 时都需要再设置此值
	    gPostMessageNewQuery.limit(SKIP_NUMBER);
	    gPostMessageNewQuery.find().then(function(postmessage){
	    	if(postmessage.length == 0){
	    		errorCallback();
	    	}else{
	    		gPostMessageGetNewAllNum += postmessage.length;
	        	successCallback(postmessage);
	    	}
	    },errorCallback);
    }
}



//获取留言列表中图片
function GetMessagePhoto(messageID,successCallback, errorCallback) {
    var Table = Bmob.Object.extend("MessagePhotos");
    var query = new Bmob.Query(Table);
    query.equalTo("messageID",messageID);
    query.select("messageID","messageOphoto","messageTphoto");
    query.find().then(function(messagephotos) {
        successCallback(messagephotos);
    },function(error){
        errorCallback(error);
    });
}
/**
 * 添加评论
 * @param ID  留言ID
 * @param commentID 评论者ID
 * @param ownerID 被评论者ID
 * @param content 评论内容
 * @param successCallback
 * @param errorCallback
 */
//function insertPOstComment(ID,commentID,ownerID,commentTime,title,content,successCallback,errorCallback){
function insertPOstComment(ID,commentID,ownerID,replyCommentID,isRead,content,successCallback,errorCallback){
	var myAccount = getMyAccount();
	if(replyCommentID == 0){
		var UserInfo = Bmob.Object.extend("UserInfo");
		var userInfoRecord = new UserInfo();
		userInfoRecord.id = myAccount.userInfoId;
		var PostComment = Bmob.Object.extend("PostComment");
		var PostComment = new PostComment();
		PostComment.set("ID", ID);
		PostComment.set("commentID", commentID);
		PostComment.set("ownerID", ownerID);
		PostComment.set("replyCommentID", replyCommentID);
		PostComment.set("isRead", isRead);
		PostComment.set("content", content);
		PostComment.set("commenterInfo", userInfoRecord);
		consoledebug.log('insertPOstComment PostComment is ' + JSON.stringify(PostComment));
		PostComment.save(null, {
			success : function(PostComment) {
				updatePostMessage(ID, function() {
					addPOstCommentUnReadNum(ownerID, function(){
		            	successCallback(PostComment);
		            }, function(error){
		            	consoledebug.log('insertPOstComment addPOstCommentUnReadNum error is '+ JSON.stringify(error));
		            })
				}, errorCallback);
			},
			error : function(error) {
				errorCallback(error);
			}
		})
	}else{
		getUserInfo(replyCommentID, function(replyUserInfo){
			consoledebug.log('insertPOstComment getUserInfo userInfo is '+ JSON.stringify(replyUserInfo));
			
			
			var UserInfo = Bmob.Object.extend("UserInfo");
		    var userInfoRecord = new UserInfo();
		    userInfoRecord.id = myAccount.userInfoId;
		    
		    var replyUserInfoRecord = new UserInfo();
		    replyUserInfoRecord.id = replyUserInfo.id;
		    
			var PostComment = Bmob.Object.extend("PostComment");
		    var PostComment = new PostComment();
		    PostComment.set("ID",ID);
		    PostComment.set("commentID", commentID);
		    PostComment.set("ownerID", ownerID);
		    PostComment.set("replyCommentID", replyCommentID);
		    PostComment.set("isRead", isRead);
		    PostComment.set("content", content);
		    PostComment.set("commenterInfo", userInfoRecord);
		    PostComment.set("replyUserInfo", replyUserInfoRecord);
		    consoledebug.log('insertPOstComment PostComment is '+ JSON.stringify(PostComment));
		   	PostComment.save(null,{
		        success: function (PostComment) {
		            updatePostMessage(ID, function(){
		            	addPOstCommentUnReadNum(ownerID, function(){
		            		successCallback(PostComment);
		            	}, function(error){
		            		consoledebug.log('insertPOstComment addPOstCommentUnReadNum error is '+ JSON.stringify(error));
		            	})
		            }, errorCallback);
		        },
		        error: function (error) {
		            errorCallback(error);
		        }
		    })
		}) 
	}
}

/*
 * 评论时，向MessageNotification表中添加未读标记数量
 */

function addPOstCommentUnReadNum(hhID, successCallback, errorCallback) {
	var MessageNotification = Bmob.Object.extend("MessageNotification");
	var query = new Bmob.Query(MessageNotification);
	query.equalTo("hhID", hhID);
	query.equalTo("messageType", "postComment");
	query.find().then(function(result){
		if(result.length > 0){
			result[0].increment("unReadNum");
			result[0].save().then(function(){
				successCallback();
			},function(){
				errorCallback(error);
			})
		}
	},function(error){
		errorCallback(error);
	})
}



function insertVoiceComment(ID,commentID,ownerID,voiceUrl,successCallback,errorCallback){
	var myAccount = getMyAccount();
	getComOneUserInfo(myAccount.hhID, function(userInfo){
		var UserInfo = Bmob.Object.extend("UserInfo");
	    var userInfoRecord = new UserInfo();
	    userInfoRecord.id = myAccount.userInfoId;
	    
		consoledebug.log('insertPOstComment getUserInfo userInfo is '+ JSON.stringify(userInfo));
		var PostComment = Bmob.Object.extend("PostComment");
	    var PostComment = new PostComment();
	    PostComment.set("ID",ID);
	    PostComment.set("commentID", commentID);
	    PostComment.set("ownerID", ownerID);
	    PostComment.set("content", '[语音评论]');
	    PostComment.set("voiceComment", voiceUrl);
	    PostComment.set("commenterInfo", userInfoRecord);
	    consoledebug.log('insertPOstComment PostComment is '+ JSON.stringify(PostComment));
	   	PostComment.save(null,{
	        success: function (PostComment) {
	            successCallback(PostComment.commentID);
	        },
	        error: function (error) {
	            errorCallback(error);
	        }
	    })
	}) 
}

/**
 * 获取评论
 */
var gCommentQuery;
var gCommentSkip = 0;
function getComments(commentID,successCallback, errorCallback){
	var PostComment = Bmob.Object.extend("PostComment");
    var query = new Bmob.Query(PostComment);
    query.equalTo("ID",commentID);
    query.limit(10);
    query.include("commenterInfo");
    query.include("replyUserInfo");
    query.ascending("createdAt");
    gCommentQuery = query;
    query.find({
    	success: function (results) {
    		gCommentSkip += results.length;
        	successCallback(results)
        },
        error: function (error) {
            errorCallback(error);
        }
    })
}

function getNextComments(successCallback, errorCallback){
    gCommentQuery.include("commenterInfo");
	gCommentQuery.skip(gCommentSkip)
    gCommentQuery.find({
    	success: function (results) {
    		gCommentSkip += results.length;
        	successCallback(results)
        },
        error: function (error) {
            errorCallback(error);
        }
    })
}

function saveMessagePhoto(elImage, w, h, photoNum,successCallback, errorCallback){
	var imagePath = $api.attr(elImage,'photoPath');
	var hhID = getMyAccount().hhID;
	//var imageExt = "." + getFileExt(imagePath);
	var imageExt = ".png";
	imgThumbnailCompress(imagePath, w, h, function(ThumbnailPath){
		consoledebug.log("photoNum is " + photoNum)
		consoledebug.log("saveMessagePhoto imgThumbnailCompress elImage is" + elImage);
		if(photoNum == 1){
			convertImgToBase64(ThumbnailPath, function(dataurl) {
				var Ophoto = "", Tphoto = '';
				var data = dataurl.split(',')[1];
				data = window.atob(data);
				var fileName = hhID + new Date().Format("-yy-MM-dd-hh:mm:ss.S") + imageExt;
				var file = BmobFile(fileName, data);
				file.save().then(function(obj) {
					Tphoto = obj.url();
					if(!Tphoto){
						file.save().then(function(obj) {
							Tphoto = obj.url();
							makePostMessagePhoto(imagePath, Tphoto,imageExt, function(Ophoto, Tphoto){
								successCallback(Ophoto, Tphoto);
							}, function(error){
								errorCallback(error);
							})
						}, function(error) {
							// the save failed.
							errorCallback(error);
						});
					}else{
						makePostMessagePhoto(imagePath, Tphoto, imageExt,function(Ophoto, Tphoto){
							successCallback(Ophoto, Tphoto);
						}, function(error){
							errorCallback(error);
						})
//						imgThumbnailCompress(imagePath, 500, 500, function(orgPath) {
//							convertImgToBase64(orgPath, function(orgDataurl) {
//								var data = orgDataurl.split(',')[1];
//								data = window.atob(data);
//								var fileName = hhID + new Date().Format("-yy-MM-dd-hh:mm:ss.S") + imageExt;
//								var tfile = BmobFile(fileName, data);
//								tfile.save().then(function(obj) {
//									Ophoto = obj.url();
//									successCallback(Ophoto, Tphoto);
//								}, function(error) {
//									file.destroy();
//									errorCallback(error);
//								})
//							});
//						})
					}
				}, function(error) {
					// the save failed.
					errorCallback(error);
				});
			})

		}else{
//			var img = new Image();
//			img.src = ThumbnailPath;
//			img.onload = function(){
//				consoledebug.log("小图片宽高为 "+img.width+" "+img.height);
//		    };
			photoClip(ThumbnailPath, w, h, function(dataurl){
		        var Ophoto = "", Tphoto = '';
		        var data = dataurl.split(',')[1];
		        data = window.atob(data);
		        var fileName = hhID + new Date().Format("-yy-MM-dd-hh:mm:ss.S") + imageExt;
		        var file = BmobFile(fileName, data);
		        file.save().then(function (obj) {
		            Tphoto = obj.url();
					
					if(!Tphoto){
						file.save().then(function (obj) {
		            		Tphoto = obj.url();
		            		makePostMessagePhoto(imagePath, Tphoto, imageExt,function(Ophoto, Tphoto){
								successCallback(Ophoto, Tphoto);
							}, function(error){
								errorCallback(error);
							})
		            	}, function (error) {
				            // the save failed.
				            errorCallback(error);
				        });
					}else{
						makePostMessagePhoto(imagePath, Tphoto, imageExt,function(Ophoto, Tphoto){
							successCallback(Ophoto, Tphoto);
						}, function(error){
							errorCallback(error);
						})
					}
		        }, function (error) {
		            // the save failed.
		            errorCallback(error);
		        });
			})
		}
	})
}


function makePostMessagePhoto(imagePath, Tphoto, imageExt, successCallback, errorCallback) {
	imgThumbnailCompress(imagePath, 500, 500, function(orgPath) {
		convertImgToBase64(orgPath, function(orgDataurl) {
			var data = orgDataurl.split(',')[1];
			data = window.atob(data);
			var fileName = hhID + new Date().Format("-yy-MM-dd-hh:mm:ss.S") + imageExt;
			var tfile = BmobFile(fileName, data);
			tfile.save().then(function(obj) {
				Ophoto = obj.url();
				if(!Ophoto){
					tfile.save().then(function(obj) {
						Ophoto = obj.url();
						successCallback(Ophoto, Tphoto);
					}, function(error) {
						file.destroy();
						errorCallback(error);
					})
				}else{
					successCallback(Ophoto, Tphoto);
				}
			}, function(error) {
				file.destroy();
				errorCallback(error);
			})
		});
	})
}


        
function showOneMessage(postmessage,geo) {
	var keys = ["postphoto","content","ownerID","voiceComment","reportNum"];
	var keys2 = ["hhID","nickName","photo","level","appraisement","sex","education","industry","age","publishTime"];
	var objPostMessage = {};
	bmob2Obj(keys, postmessage, objPostMessage);
	objPostMessage.content = formatStr(objPostMessage.content);
	objPostMessage.ID = postmessage.id;
	var ownerInfo = postmessage.get("ownerInfo");
	bmob2Obj(keys2, ownerInfo, objPostMessage);
	var date = new Date();
	consoledebug.log('date2 is ' + postmessage.createdAt);
	var date2 = new Date(postmessage.createdAt.replace(new RegExp("-","gm"),"/"));
	var d = date.getTime() - date2.getTime();
	var min = d / (60000);
	if (min > 1440){
		var t = min/1440;
		objPostMessage.publishTime = Math.floor(t) + '天前';
	} else if (min<2880&&min>1440){
		objPostMessage.publishTime = '昨天'	
	} else if (min > 59) {
		var h = min / 60;
		objPostMessage.publishTime = Math.floor(h) + '小时前';
	} else {
		objPostMessage.publishTime = Math.floor(min) + '分钟前';
	}

	if (postmessage.get("location") != undefined) {
		var miles = geo.kilometersTo(postmessage.get("location")) * 1000;
		if (miles > 10000) {
			miles = miles / 1000;
			objPostMessage.location = Math.ceil(miles) + "km";
			//距离位置信息
		} else if (miles > 1000) {
			miles = miles / 1000;
			objPostMessage.location = miles.toFixed(1) + "km";
			//距离位置信息
		} else {
			objPostMessage.location = Math.ceil(miles) + "m";
			//距离位置信息
		}
	}
	consoledebug.log('objPostMessage.location is ' + JSON.stringify(objPostMessage.location));
	uiAppendPostMessage(objPostMessage)
	//						postMessage.push(objPostMessage);
//	postMessage[objPostMessage.ID] = objPostMessage;
	var messageID = postmessage.id;
	consoledebug.log("messageID is " + messageID)
	GetMessagePhoto(postmessage.id, function(messagephotos) {
		consoledebug.log('getMessageList GetPostMessage messagephotos is ' + JSON.stringify(messagephotos));
		consoledebug.log('getMessageList GetPostMessage objPostMessage is ' + JSON.stringify(objPostMessage));
		
		if(messagephotos.length == 1){
			var messageTPhotosList = [];
			var messageOPhotosList = [];
			messageTPhotosList.push(messagephotos[0].get("messageTphoto"));
			messageOPhotosList.push(messagephotos[0].get("messageOphoto"));
			objPostMessage.Tphotos = messageTPhotosList;
			objPostMessage.Ophotos = messageOPhotosList;
		}else{
			var messageTPhotosList = [];
			var messageOPhotosList = [];
			for (var j = 0; j < messagephotos.length; j++) {
				messageTPhotosList.push(messagephotos[j].get("messageTphoto"));
				messageOPhotosList.push(messagephotos[j].get("messageOphoto"));
			}
			objPostMessage.Tphotos = messageTPhotosList;
			objPostMessage.Ophotos = messageOPhotosList;
		}
		
		consoledebug.log("objPostMessage is " + " " + JSON.stringify(objPostMessage))
		uiPostMessagePhotos(objPostMessage)
		postMessage.push(objPostMessage);
		getComments(messageID,function(results) {
			consoledebug.log("getComments is " + JSON.stringify(results))
			if(results.length > 0){
				var postCommentsInfo = [];
				var keys = ["ID", "content", "ownerID","voiceComment","commentID","replyCommentID","isRead"];
				var keys2 = ["hhID", "nickName", "photo"];
				for (var i = 0; i < results.length; i++) {
					var objPostComments = {};
					objPostComments.objID = results[i].id
					var replyUserInfo = results[i].get("replyUserInfo");
					if(replyUserInfo){
						objPostComments.replyUserName = replyUserInfo.get("nickName");
					}
					
					bmob2Obj(keys, results[i], objPostComments);
					var commenterInfo = results[i].get("commenterInfo");
					bmob2Obj(keys2, commenterInfo, objPostComments);
					postCommentsInfo.push(objPostComments);
				}
			}
			uiPostMessageComments(postCommentsInfo)
		}, function(error) {
			consoledebug.log('getMessageList getComments is ' + JSON.stringify(error));
		})
	}, function(error) {
		consoledebug.log('getMessageList GetPostMessage error is ' + JSON.stringify(error));
	});
}

function showNewMessage(postmessage,geo,newComments) {
	var keys = ["postphoto","content","ownerID","voiceComment","reportNum"];
	var keys2 = ["hhID","nickName","photo","level","appraisement","sex","education","industry","age","publishTime"];
	var objPostMessage = {};
	bmob2Obj(keys, postmessage, objPostMessage);
	objPostMessage.content = formatStr(objPostMessage.content);
	objPostMessage.ID = postmessage.id;
	var ownerInfo = postmessage.get("ownerInfo");
	bmob2Obj(keys2, ownerInfo, objPostMessage);
	var date = new Date();
	consoledebug.log('date2 is ' + postmessage.createdAt);
	var date2 = new Date(postmessage.createdAt.replace(new RegExp("-","gm"),"/"));
	var d = date.getTime() - date2.getTime();
	var min = d / (60000);
	if (min > 1440){
		var t = min/1440;
		objPostMessage.publishTime = Math.floor(t) + '天前';
	} else if (min<2880&&min>1440){
		objPostMessage.publishTime = '昨天'	
	} else if (min > 59) {
		var h = min / 60;
		objPostMessage.publishTime = Math.floor(h) + '小时前';
	} else {
		objPostMessage.publishTime = Math.floor(min) + '分钟前';
	}

	if (postmessage.get("location") != undefined) {
		var miles = geo.kilometersTo(postmessage.get("location")) * 1000;
		if (miles > 10000) {
			miles = miles / 1000;
			objPostMessage.location = Math.ceil(miles) + "km";
			//距离位置信息
		} else if (miles > 1000) {
			miles = miles / 1000;
			objPostMessage.location = miles.toFixed(1) + "km";
			//距离位置信息
		} else {
			objPostMessage.location = Math.ceil(miles) + "m";
			//距离位置信息
		}
	}
	consoledebug.log('objPostMessage.location is ' + JSON.stringify(objPostMessage.location));
	uiAppendPostMessage(objPostMessage)
	//						postMessage.push(objPostMessage);
//	postMessage[objPostMessage.ID] = objPostMessage;
	var messageID = postmessage.id;
	consoledebug.log("messageID is " + messageID)
	GetMessagePhoto(postmessage.id, function(messagephotos) {
		consoledebug.log('getMessageList GetPostMessage messagephotos is ' + JSON.stringify(messagephotos));
		consoledebug.log('getMessageList GetPostMessage objPostMessage is ' + JSON.stringify(objPostMessage));
		
		if(messagephotos.length == 1){
			var messageTPhotosList = [];
			var messageOPhotosList = [];
			messageTPhotosList.push(messagephotos[0].get("messageTphoto"));
			messageOPhotosList.push(messagephotos[0].get("messageOphoto"));
			objPostMessage.Tphotos = messageTPhotosList;
			objPostMessage.Ophotos = messageOPhotosList;
		}else{
			var messageTPhotosList = [];
			var messageOPhotosList = [];
			for (var j = 0; j < messagephotos.length; j++) {
				messageTPhotosList.push(messagephotos[j].get("messageTphoto"));
				messageOPhotosList.push(messagephotos[j].get("messageOphoto"));
			}
			objPostMessage.Tphotos = messageTPhotosList;
			objPostMessage.Ophotos = messageOPhotosList;
		}
		
		consoledebug.log("objPostMessage is " + " " + JSON.stringify(objPostMessage))
		uiPostMessagePhotos(objPostMessage)
		postMessage.push(objPostMessage);
		
//		getComments(messageID,function(results) {
//			consoledebug.log("getComments is " + JSON.stringify(results))
//			
//			uiPostMessageComments(postCommentsInfo)
//		}, function(error) {
//			consoledebug.log('getMessageList getComments is ' + JSON.stringify(error));
//		})
	}, function(error) {
		consoledebug.log('getMessageList GetPostMessage error is ' + JSON.stringify(error));
	});
}

function getCommentsInfo(commentID) {
	consoledebug.log("commentID is " + commentID)
	getComments(commentID, function(results) {
		consoledebug.log("getComments is " + JSON.stringify(results))
		var postCommentsInfo = [];
		var keys = ["ID", "content", "ownerID", "voiceComment"];
		var keys2 = ["hhID", "nickName", "photo"];
		for (var i = 0; i < results.length; i++) {
			var objPostComments = {};
			
			var replyUserInfo = results[i].get("replyUserInfo");
			if(replyUserInfo){
				objPostComments.replyUserName = replyUserInfo[0].get("nickName");
			}
			
			bmob2Obj(keys, results[i], objPostComments);
			var commenterInfo = results[i].get("commenterInfo");
			bmob2Obj(keys2, commenterInfo, objPostComments);
			postCommentsInfo.push(objPostComments);
		}
		uiPostMessageComments(postCommentsInfo)
	}, function(error) {
		consoledebug.log('getMessageList getComments is ' + JSON.stringify(error));
	})
}

//判断自己的留言是否被评论  或  有人回复评论
function judgeIsNoReadComment(ownerID,isRead,successCallback, errorCallback){
	var PostComment = Bmob.Object.extend("PostComment");
    var query1 = new Bmob.Query(PostComment);
    query1.equalTo("ownerID",ownerID);
    query1.equalTo("isRead",isRead);
    
    var query2 = new Bmob.Query(PostComment);
    query2.equalTo("replyCommentID",ownerID);
    query2.equalTo("isRead",isRead);
    var query = Bmob.Query.or(query1, query2);
    query.count({
	  success: function(count) {
	    	successCallback(count)
	  },
	  error: function(error) {
	    	errorCallback(error)
	  }
	});
}

//获取有新消息的评论并且修改未读标记
function changeNoReadCommentState(ownerID,isRead,successCallback, errorCallback){
	var promises = [];
    var promise = new Bmob.Promise();

	var PostComment = Bmob.Object.extend("PostComment");
    var query1 = new Bmob.Query(PostComment);
    query1.equalTo("ownerID",ownerID);
    query1.equalTo("isRead",isRead);
    
    var query2 = new Bmob.Query(PostComment);
//  query2.equalTo("commentID",ownerID);
	query2.equalTo("replyCommentID",ownerID);
    query2.equalTo("isRead",isRead);
    var query = Bmob.Query.or(query1, query2);
    query.descending("createdAt");
    query.include("commenterInfo");
	query.include("replyUserInfo");
    query.find(function(result){
    	for(var i = 0; i < result.length; i++){
    		result[i].set("isRead",0);
//  		result[i].save();
			promises.push(result[i].save());
    	}
    	promise.resolve(result);
//  	successCallback(result);
    },function(){
//  	errorCallback()
    	promise.reject(error);
    });
    return promise;
}

//获取有新消息的留言
function getNoReadCommentInfo(ownerID,isRead,successCallback, errorCallback){
	var PostMessageInfo = Bmob.Object.extend("PostMessageInfo");
    var query = new Bmob.Query(PostMessageInfo);

	var PostComment = Bmob.Object.extend("PostComment");
    var query1 = new Bmob.Query(PostComment);
    query1.equalTo("ownerID",ownerID);
    query1.equalTo("isRead",isRead);
    
    var query2 = new Bmob.Query(PostComment);
    query2.equalTo("replyCommentID",ownerID);
    query2.equalTo("isRead",isRead);
    var query3 = Bmob.Query.or(query1, query2);
    
    query.matchesKeyInQuery("objectId", "ID", query3);
    query.descending("createdAt");
    query.include("commenterInfo");
	query.include("ownerInfo");
    query.find(function(result){
    	successCallback(result);
    },function(error){
    	errorCallback(error)
    });
}

	function formatStr(str){
		if(str != undefined){
			str=str.replace(/\n/ig,"<br/>");
			str=str.replace(/ /ig,"&nbsp");
		}
		return str;
   }

